@@ -7,6 +7,7 @@ this.energy = null;
 this.nXX = 0;
 this.symLine = null;
 this.isADF = false;
+this.lastModel = -1;
 if (!Clazz.isClassDefined ("J.adapter.readers.quantum.AdfReader.SymmetryData")) {
 J.adapter.readers.quantum.AdfReader.$AdfReader$SymmetryData$ ();
 }
@@ -32,6 +33,9 @@ return true;
 if (!this.doGetModel (++this.modelNumber, null)) return this.checkLastModel ();
 this.readCoordinates ();
 return true;
+}if (this.line.startsWith ("Atomic charges")) {
+this.readCharges ();
+return true;
 }if (this.line.indexOf (" ======  Eigenvectors (rows) in BAS representation") >= 0) {
 if (this.doReadMolecularOrbitals) this.readMolecularOrbitals (JU.PT.getTokens (this.symLine)[1]);
 return true;
@@ -79,6 +83,7 @@ Clazz.defineMethod (c$, "readCoordinates",
 function () {
 var isGeometry = (!this.isADF || this.line.indexOf ("G E O M E T R Y") >= 0);
 this.asc.newAtomSet ();
+this.lastModel = this.asc.iSet;
 var modelName = "model " + String.valueOf (this.modelNumber);
 if (this.energy != null) modelName = modelName + " e=" + this.energy + " a.u.";
 this.asc.setAtomSetName (modelName);
@@ -264,6 +269,23 @@ mo.put ("energy", Float.$valueOf (energy));
 mo.put ("symmetry", sd.sym + "_" + moPt);
 this.setMO (mo);
 }, "~S,~N,~N,~N");
+Clazz.defineMethod (c$, "readCharges", 
+ function () {
+if (this.lastModel < 0) return;
+this.rd ();
+this.rd ();
+var n = this.asc.getAtomSetAtomCount (this.lastModel);
+var charges =  Clazz.newFloatArray (n, 0);
+for (var i = 0; i < n; i++) {
+this.rd ();
+var tokens = this.getTokens ();
+var iatom = this.parseIntStr (tokens[0]);
+charges[iatom - 1] = this.parseFloatStr (tokens[2]);
+}
+for (var p = 0, i = this.asc.getAtomSetAtomIndex (this.lastModel); i < this.asc.ac; i++, p = (p + 1) % n) {
+this.asc.atoms[i].partialCharge = charges[p];
+}
+});
 c$.$AdfReader$SymmetryData$ = function () {
 Clazz.pu$h(self.c$);
 c$ = Clazz.decorateAsClass (function () {
