@@ -141,7 +141,7 @@ if (collection.reader != null && collection.reader.mustFinalizeModelSet) this.re
 var existingAtomsCount = this.ac;
 this.setInfo ("loadState", collection.atomSetInfo.get ("loadState"));
 if (collection.bsAtoms != null) {
-if (this.bsAtoms == null) this.bsAtoms =  new JU.BS ();
+this.getBSAtoms (0);
 for (var i = collection.bsAtoms.nextSetBit (0); i >= 0; i = collection.bsAtoms.nextSetBit (i + 1)) this.bsAtoms.set (existingAtomsCount + i);
 
 }var clonedAtoms = 0;
@@ -846,5 +846,23 @@ Clazz.defineMethod (c$, "checkNoEmptyModel",
 function () {
 while (this.atomSetCount > 0 && this.atomSetAtomCounts[this.atomSetCount - 1] == 0) this.atomSetCount--;
 
+});
+Clazz.defineMethod (c$, "getBSAtoms", 
+function (n) {
+if (this.bsAtoms == null) {
+this.bsAtoms =  new JU.BS ();
+if (n != 0) this.bsAtoms.setBits (0, (n < 0 ? this.ac : n));
+}return this.bsAtoms;
+}, "~N");
+Clazz.defineMethod (c$, "fix2Stereo", 
+function () {
+this.getBSAtoms (-1);
+for (var i = this.bondCount; --i >= 0; ) {
+var b = this.bonds[i];
+if (this.atoms[b.atomIndex2].elementSymbol.equals ("H") && b.order != 1025 && b.order != 1041 && this.atoms[b.atomIndex1].elementSymbol.equals ("C")) {
+this.bsAtoms.clear (b.atomIndex2);
+} else if (this.atoms[b.atomIndex1].elementSymbol.equals ("H") && this.atoms[b.atomIndex2].elementSymbol.equals ("C")) {
+this.bsAtoms.clear (b.atomIndex1);
+}}
 });
 });
