@@ -23,7 +23,7 @@ try {
 var mi = this.vwr.ms.at[bs.nextSetBit (0)].mi;
 var uc = this.vwr.getCurrentUnitCell ();
 this.haveUnitCell = (uc != null);
-if (!this.haveUnitCell) uc = this.vwr.getSymTemp ().setUnitCell ( Clazz.newFloatArray (-1, [1, 1, 1, 90, 90, 90]), false);
+if (!this.haveUnitCell) uc = this.vwr.getSymTemp ().setUnitCell (null, false);
 var offset = uc.getFractionalOffset ();
 var fractionalOffset = offset != null && (offset.x != Clazz.floatToInt (offset.x) || offset.y != Clazz.floatToInt (offset.y) || offset.z != Clazz.floatToInt (offset.z));
 var fset;
