@@ -299,20 +299,25 @@ var valueBlue = jvxlData.valueMappedToBlue;
 var valueRed = jvxlData.valueMappedToRed;
 var vertexCount = (jvxlData.saveVertexCount > 0 ? jvxlData.saveVertexCount : jvxlData.vertexCount);
 if (vertexCount > vertexValues.length) System.out.println ("JVXLCODER ERROR");
-var min = jvxlData.mappedDataMin;
-var max = jvxlData.mappedDataMax;
+var isPrecisionColor = jvxlData.isJvxlPrecisionColor;
+var min = (isPrecisionColor ? jvxlData.mappedDataMin : jvxlData.valueMappedToRed);
+var max = (isPrecisionColor ? jvxlData.mappedDataMax : jvxlData.valueMappedToBlue);
+if (vertexValues.length < vertexCount) System.out.println ("JVXLCOLOR OHOHO");
+jvxlData.jvxlColorData = J.jvxl.data.JvxlCoder.jvxlEncodeColorData (vertexValues, min, max, colorFractionBase, colorFractionRange, jvxlData.isTruncated, isPrecisionColor);
+}, "J.jvxl.data.JvxlData,~A");
+c$.jvxlEncodeColorData = Clazz.defineMethod (c$, "jvxlEncodeColorData", 
+function (vertexValues, min, max, colorFractionBase, colorFractionRange, doTruncate, isPrecisionColor) {
 var list1 =  new JU.SB ();
 var list2 =  new JU.SB ();
-if (vertexValues.length < vertexCount) System.out.println ("JVXLCOLOR OHOHO");
-for (var i = 0; i < vertexCount; i++) {
+for (var i = 0, n = vertexValues.length; i < n; i++) {
 var value = vertexValues[i];
 if (Float.isNaN (value)) value = min;
 if (doTruncate) value = (value > 0 ? 0.999 : -0.999);
-if (writePrecisionColor) J.jvxl.data.JvxlCoder.jvxlAppendCharacter2 (value, min, max, colorFractionBase, colorFractionRange, list1, list2);
- else list1.appendC (J.jvxl.data.JvxlCoder.jvxlValueAsCharacter (value, valueRed, valueBlue, colorFractionBase, colorFractionRange));
+if (isPrecisionColor) J.jvxl.data.JvxlCoder.jvxlAppendCharacter2 (value, min, max, colorFractionBase, colorFractionRange, list1, list2);
+ else list1.appendC (J.jvxl.data.JvxlCoder.jvxlValueAsCharacter (value, min, max, colorFractionBase, colorFractionRange));
 }
-jvxlData.jvxlColorData = list1.appendSB (list2).appendC ('\n').toString ();
-}, "J.jvxl.data.JvxlData,~A");
+return list1.appendSB (list2).appendC ('\n').toString ();
+}, "~A,~N,~N,~N,~N,~B,~B");
 c$.appendXmlVertexOnlyData = Clazz.defineMethod (c$, "appendXmlVertexOnlyData", 
  function (sb, jvxlData, meshData, escapeXml) {
 var vertexIdNew =  Clazz.newIntArray (meshData.vc, 0);
