@@ -689,6 +689,7 @@ bsAtoms.and (bs);
 if (!isP1) bsAtoms.and (bsCell);
 }var noAtoms = bsAtoms.isEmpty ();
 if (mi < 0) mi = (noAtoms ? 0 : this.vwr.ms.at[bsAtoms.nextSetBit (0)].getModelIndex ());
+this.vwr.ms.getModelAuxiliaryInfo (mi).remove ("spaceGroupInfo");
 var sym = this.vwr.getOperativeSymmetry ();
 if (sym == null) sym = this.vwr.getSymTemp ().setUnitCell ( Clazz.newFloatArray (-1, [10, 10, 10, 90, 90, 90]), false);
 var m = sym.getUnitCellMultiplier ();
@@ -699,7 +700,7 @@ var oabc;
 var ita;
 var basis;
 var sg = null;
-var sgInfo = (noAtoms || isP1 ? null : this.vwr.findSpaceGroup (isDefined ? null : bsAtoms, isDefined ? name : null, sym.getUnitCellParams (), false, true));
+var sgInfo = (noAtoms && !isDefined || isP1 ? null : this.vwr.findSpaceGroup (isDefined ? null : bsAtoms, isDefined ? name : null, sym.getUnitCellParams (), false, true));
 if (sgInfo == null) {
 name = "P1";
 supercell = JU.P3.new3 (1, 1, 1);
@@ -720,7 +721,9 @@ if (basis == null) basis = sym.removeDuplicates (this.vwr.ms, bsAtoms, true);
 this.vwr.ms.setSpaceGroup (mi, sym, basis);
 var pt = JU.SimpleUnitCell.ptToIJK (supercell, 1);
 JM.ModelSet.setUnitCellOffset (sym, pt, 0);
-return name + " basis=" + basis;
+if (noAtoms) {
+this.appRunScript ("unitcell on; center unitcell;axes unitcell; axes on;set perspectivedepth false;moveto 0 axis c1;draw delete;show spacegroup");
+}return name + " basis=" + basis;
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
 if (!JV.Viewer.isJS) e.printStackTrace ();
