@@ -15,6 +15,7 @@ this.s0f = null;
 this.s1f = null;
 this.s2f = null;
 this.bsHandles = null;
+this.haveNotifiedHandles = false;
 Clazz.instantialize (this, arguments);
 }, J.renderspecial, "DrawRenderer", J.render.MeshRenderer);
 Clazz.prepareFields (c$, function () {
@@ -46,7 +47,7 @@ for (var j = 0; j < 4; j++) mesh.vs[j] = (c[j] < 0 ? mesh.vs[j - 1] : this.vwr.m
 
 mesh.recalcAltVertices = true;
 }if (this.renderMesh2 (mesh)) this.renderInfo ();
-if (!this.isExport && mesh.visibilityFlags != 0 && this.vwr.getPickingMode () == 4) {
+if (!this.isExport && mesh.visibilityFlags != 0 && (this.vwr.getDrawHover () || this.vwr.getPickingMode () == 4)) {
 if (!this.g3d.setC (JU.C.getColixTranslucent3 (23, true, 0.5))) this.needTranslucent = true;
  else this.renderHandles ();
 }}
@@ -339,8 +340,13 @@ for (var j = (this.dmesh.isDrawPolygon ? 3 : vertexIndexes.length); --j >= 0; )
 var k = vertexIndexes[j];
 if (this.bsHandles.get (k)) continue;
 this.bsHandles.set (k);
+if (k >= this.screens.length) {
+if (!this.haveNotifiedHandles) {
+System.out.println ("DrawRender handles k >= screens.length " + k + " ");
+this.haveNotifiedHandles = true;
+}} else {
 this.g3d.drawFilledCircle (23, colixFill, diameter, this.screens[k].x, this.screens[k].y, this.screens[k].z);
-}
+}}
 }
 break;
 }
