@@ -120,7 +120,7 @@ Clazz.defineMethod (c$, "coordinateInRange",
 function (x, y, vertex, dmin2, ptXY) {
 this.vwr.tm.transformPtScr (vertex, ptXY);
 var d2 = (x - ptXY.x) * (x - ptXY.x) + (y - ptXY.y) * (y - ptXY.y);
-return (d2 < dmin2 ? d2 : -1);
+return (d2 <= dmin2 ? d2 : -1);
 }, "~N,~N,JU.T3,~N,JU.P3i");
 Clazz.defineMethod (c$, "getColixI", 
 function (colix, paletteID, atomIndex) {
