@@ -43,6 +43,11 @@ this.slabData = null;
 this.vAB = null;
 this.ptXY = null;
 this.defaultFontSize = 16.0;
+this.pm2 = null;
+this.dmin22 = 0;
+this.pmod2 = 0;
+this.pickedVertex2 = 0;
+this.pickedPoint2 = null;
 Clazz.instantialize (this, arguments);
 }, J.shapespecial, "Draw", J.shape.MeshCollection);
 Clazz.prepareFields (c$, function () {
@@ -235,6 +240,9 @@ return;
 }if ("modelBasedPoints" === propertyName) {
 this.addPoints (5, value);
 return;
+}if ("hoverlabel" === propertyName) {
+propertyName = "title";
+value = "<hover>" + value;
 }if ("title" === propertyName) {
 if (this.thisMesh != null) {
 this.thisMesh.title = this.setTitle (value);
@@ -287,6 +295,21 @@ this.meshes[i].modelIndex--;
 }}
 this.resetObjects ();
 }, "~N");
+Clazz.defineMethod (c$, "setTitle", 
+function (value) {
+if (Clazz.instanceOf (value, String)) {
+var lines = value;
+if (lines.startsWith ("<hover>")) {
+var s = lines.substring (7);
+var i = s.indexOf ("</hover>");
+if (i >= 0) {
+this.thisMesh.hoverLabel = s.substring (0, i);
+value = s.substring (i + 8);
+} else {
+this.thisMesh.hoverLabel = s;
+value = s;
+}}}return Clazz.superCall (this, J.shapespecial.Draw, "setTitle", [value]);
+}, "~O");
 Clazz.defineMethod (c$, "deleteMeshElement", 
  function (i) {
 if (this.meshes[i] === this.currentMesh) this.currentMesh = this.thisMesh = null;
@@ -851,10 +874,7 @@ function (x, y, bsVisible) {
 if (!this.vwr.getDrawHover ()) return false;
 if (JU.C.isColixTranslucent (this.colix)) return false;
 if (!this.findPickedObject (x, y, false, bsVisible)) return false;
-if (this.vwr.gdata.antialiasEnabled) {
-x <<= 1;
-y <<= 1;
-}var s = (this.pickedMesh.title == null ? this.pickedMesh.thisID : this.pickedMesh.title[0]);
+var s = ((this.pickedMesh).hoverLabel != null ? (this.pickedMesh).hoverLabel : this.pickedMesh.title == null ? this.pickedMesh.thisID : this.pickedMesh.title[0]);
 if (s.length > 1 && s.charAt (0) == '>') s = s.substring (1);
 this.vwr.hoverOnPt (x, y, s, this.pickedMesh.thisID, this.pickedPt);
 return true;
@@ -912,26 +932,57 @@ if (this.vwr.gdata.isAntialiased ()) {
 x <<= 1;
 y <<= 1;
 dmin2 <<= 1;
-}this.pickedModel = 0;
-this.pickedVertex = 0;
+}this.pickedModel = this.pickedVertex = 0;
 this.pickedMesh = null;
+this.pickedPt = null;
+this.pm2 = null;
+this.pickedPoint2 = null;
+this.dmin22 = this.pmod2 = this.pickedVertex2 = -1;
 for (var i = 0; i < this.meshCount; i++) {
 var m = this.dmeshes[i];
-if (m.visibilityFlags != 0) {
+if (m.visibilityFlags == 0) continue;
+dmin2 = this.pickClosestPoint (dmin2, x, y, m, -1, -1, this.ptXY, null);
+}
+if (dmin2 != 0 && this.dmin22 == dmin2 && this.pickedMesh != null && this.pm2 != null) {
+var vTemp =  new JU.V3 ();
+var d1 = this.pickClosestPoint (2147483647, x, y, this.pickedMesh, this.pickedModel, this.pickedVertex, this.ptXY, vTemp);
+var d2 = this.pickClosestPoint (d1, x, y, this.pm2, this.pmod2, this.pickedVertex2, this.ptXY, vTemp);
+if (d2 < d1) {
+this.pickedMesh = this.pm2;
+this.pickedModel = this.pmod2;
+this.pickedVertex = this.pickedVertex2;
+this.pickedPt = this.pickedPoint2;
+}}return (this.pickedMesh != null);
+}, "~N,~N,~B,JU.BS");
+Clazz.defineMethod (c$, "pickClosestPoint", 
+ function (dmin2, x, y, m, model, vnot, ptXY, vTemp) {
 var mCount = (m.isDrawPolygon ? m.pc : m.modelFlags == null ? 1 : this.ms.mc);
 for (var iModel = mCount; --iModel >= 0; ) {
-if (m.modelFlags != null && !m.modelFlags.get (iModel) || m.pis == null || !m.isDrawPolygon && (iModel >= m.pis.length || m.pis[iModel] == null)) continue;
+if (model >= 0 ? iModel != model : m.modelFlags != null && !m.modelFlags.get (iModel) || m.pis == null || !m.isDrawPolygon && (iModel >= m.pis.length || m.pis[iModel] == null)) continue;
 for (var iVertex = (m.isDrawPolygon ? 3 : m.pis[iModel].length); --iVertex >= 0; ) {
+if (iVertex == vnot) continue;
 try {
 var iv = m.pis[iModel][iVertex];
 var pt = (m.altVertices == null ? m.vs[iv] : m.altVertices[iv]);
-var d2 = this.coordinateInRange (x, y, pt, dmin2, this.ptXY);
+if (vnot >= 0) {
+vTemp.sub2 (pt, this.pickedPt);
+if (vTemp.length () == 0) continue;
+vTemp.normalize ();
+vTemp.add (this.pickedPt);
+}var d2 = this.coordinateInRange (x, y, (vnot >= 0 ? vTemp : pt), dmin2, ptXY);
 if (d2 >= 0) {
-this.pickedMesh = m;
-dmin2 = d2;
-this.pickedModel = iModel;
-this.pickedVertex = iVertex;
+if (vnot < 0) {
+if (this.pm2 == null) {
+this.dmin22 = d2;
+this.pmod2 = this.pickedModel;
+this.pm2 = this.pickedMesh;
+this.pickedVertex2 = this.pickedVertex;
+this.pickedPoint2 = this.pickedPt;
+}this.pickedVertex = iVertex;
 this.pickedPt = pt;
+this.pickedMesh = m;
+this.pickedModel = iModel;
+}dmin2 = d2;
 }} catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
 System.out.println (e);
@@ -941,9 +992,8 @@ throw e;
 }
 }
 }
-}}
-return (this.pickedMesh != null);
-}, "~N,~N,~B,JU.BS");
+return dmin2;
+}, "~N,~N,~N,J.shapespecial.DrawMesh,~N,~N,JU.P3i,JU.V3");
 Clazz.defineMethod (c$, "getCommand", 
  function (mesh) {
 if (mesh != null) return this.getCommand2 (mesh, mesh.modelIndex);
@@ -1049,11 +1099,14 @@ dmesh.mat4.getTranslation (v);
 str.append (" offset ").append (JU.Escape.eP (v));
 }if (dmesh.titleColor != null) {
 str.append (" title color ").append (JU.Escape.escapeColor (dmesh.titleColor.intValue ()));
-}if (dmesh.title != null) {
-var s = "";
-for (var i = 0; i < dmesh.title.length; i++) s += "|" + dmesh.title[i];
+}var title = "";
+if (dmesh.title != null) {
+for (var i = 0; i < dmesh.title.length; i++) title += "|" + dmesh.title[i];
 
-str.append (" ").append (JU.PT.esc (s.substring (1)));
+}if (dmesh.hoverLabel != null) {
+title = "|<hover>" + dmesh.hoverLabel + "</hover>" + (title === "" ? "" : title.substring (1));
+}if (title.length > 1) {
+str.append (" ").append (JU.PT.esc (title.substring (1)));
 }if (dmesh.fontID >= 0) {
 str.append (" font " + JU.Font.getFont3D (dmesh.fontID).getInfo ());
 }str.append (";\n");
