@@ -7,7 +7,7 @@ this.atomSite = 0;
 this.group = null;
 this.userDefinedVanDerWaalRadius = 0;
 this.valence = 0;
-this.atomicAndIsotopeNumber = 0;
+this.atomNumberFlags = 0;
 this.atomSymmetry = null;
 this.formalChargeAndFlags = 0;
 this.madAtom = 0;
@@ -29,11 +29,11 @@ this.mi = modelIndex;
 this.atomSymmetry = atomSymmetry;
 this.atomSite = atomSite;
 this.i = atomIndex;
-this.atomicAndIsotopeNumber = atomicAndIsotopeNumber;
+this.atomNumberFlags = atomicAndIsotopeNumber;
 if (isHetero) this.formalChargeAndFlags = 2;
 if (formalCharge != 0 && formalCharge != -2147483648) this.setFormalCharge (formalCharge);
 this.userDefinedVanDerWaalRadius = radius;
-this.setT (xyz);
+if (xyz != null) this.setT (xyz);
 return this;
 }, "~N,~N,JU.P3,~N,JU.BS,~N,~N,~N,~B");
 Clazz.defineMethod (c$, "setShapeVisibility", 
@@ -165,24 +165,24 @@ this.colixAtom = JU.C.getColixTranslucent3 (this.colixAtom, isTranslucent, trans
 }, "~B,~N");
 Clazz.overrideMethod (c$, "getElementNumber", 
 function () {
-return JU.Elements.getElementNumber (this.atomicAndIsotopeNumber);
+return JU.Elements.getElementNumber (this.atomNumberFlags);
 });
 Clazz.overrideMethod (c$, "getIsotopeNumber", 
 function () {
-return JU.Elements.getIsotopeNumber (this.atomicAndIsotopeNumber);
+return JU.Elements.getIsotopeNumber (this.atomNumberFlags);
 });
 Clazz.overrideMethod (c$, "getAtomicAndIsotopeNumber", 
 function () {
-return this.atomicAndIsotopeNumber;
+return this.atomNumberFlags;
 });
 Clazz.defineMethod (c$, "setAtomicAndIsotopeNumber", 
 function (n) {
 if (n < 0 || (n & 127) >= JU.Elements.elementNumberMax || n > 32767) n = 0;
-this.atomicAndIsotopeNumber = n;
+this.atomNumberFlags = n;
 }, "~N");
 Clazz.defineMethod (c$, "getElementSymbolIso", 
 function (withIsotope) {
-return JU.Elements.elementSymbolFromNumber (withIsotope ? this.atomicAndIsotopeNumber : this.atomicAndIsotopeNumber & 127);
+return JU.Elements.elementSymbolFromNumber (withIsotope ? this.atomNumberFlags : this.atomNumberFlags & 127);
 }, "~B");
 Clazz.defineMethod (c$, "getElementSymbol", 
 function () {
@@ -348,7 +348,7 @@ return (dimension == 0 ? this.x : (dimension == 1 ? this.y : this.z));
 }, "~N");
 Clazz.defineMethod (c$, "getVanderwaalsRadiusFloat", 
 function (vwr, type) {
-return (Float.isNaN (this.userDefinedVanDerWaalRadius) ? vwr.getVanderwaalsMarType (this.atomicAndIsotopeNumber, this.getVdwType (type)) / 1000 : this.userDefinedVanDerWaalRadius);
+return (Float.isNaN (this.userDefinedVanDerWaalRadius) ? vwr.getVanderwaalsMarType (this.atomNumberFlags, this.getVdwType (type)) / 1000 : this.userDefinedVanDerWaalRadius);
 }, "JV.Viewer,J.c.VDW");
 Clazz.defineMethod (c$, "getVdwType", 
  function (type) {
@@ -367,7 +367,7 @@ Clazz.defineMethod (c$, "getBondingRadius",
 function () {
 var rr = this.group.chain.model.ms.bondingRadii;
 var r = (rr == null || this.i >= rr.length ? 0 : rr[this.i]);
-return (r == 0 ? JU.Elements.getBondingRadius (this.atomicAndIsotopeNumber, this.getFormalCharge ()) : r);
+return (r == 0 ? JU.Elements.getBondingRadius (this.atomNumberFlags, this.getFormalCharge ()) : r);
 });
 Clazz.defineMethod (c$, "getVolume", 
 function (vwr, vType) {
@@ -597,6 +597,12 @@ Clazz.defineMethod (c$, "getInfo",
 function () {
 return this.getIdentity (2);
 });
+Clazz.defineMethod (c$, "getIdentityXYZ", 
+function (pt, mode) {
+pt = (mode == 3 || this.group.chain.model.isJmolDataFrame ? this.getFractionalCoordPt (!this.group.chain.model.ms.vwr.g.legacyJavaFloat, false, pt) : this);
+var s = (mode == 3 ? "" : this.getIdentity (mode) + " ") + JU.PT.formatF (pt.x, 0, 3, true, true) + " " + JU.PT.formatF (pt.y, 0, 3, true, true) + " " + JU.PT.formatF (pt.z, 0, 3, true, true);
+return s;
+}, "JU.P3,~N");
 Clazz.defineMethod (c$, "getIdentity", 
 function (mode) {
 var info =  new JU.SB ();
@@ -631,12 +637,6 @@ info.append (this.getModelNumberForLabel ());
 info.appendI (this.getAtomNumber ());
 }return info.toString ();
 }, "~N");
-Clazz.defineMethod (c$, "getIdentityXYZ", 
-function (pt, mode) {
-pt = (mode == 3 || this.group.chain.model.isJmolDataFrame ? this.getFractionalCoordPt (!this.group.chain.model.ms.vwr.g.legacyJavaFloat, false, pt) : this);
-var s = (mode == 3 ? "" : this.getIdentity (mode) + " ") + JU.PT.formatF (pt.x, 0, 3, true, true) + " " + JU.PT.formatF (pt.y, 0, 3, true, true) + " " + JU.PT.formatF (pt.z, 0, 3, true, true);
-return s;
-}, "JU.P3,~N");
 Clazz.overrideMethod (c$, "getGroup3", 
 function (allowNull) {
 var group3 = this.group.getGroup3 ();
@@ -766,7 +766,7 @@ case 1086326789:
 case 1094715402:
 return this.getElementNumber ();
 case 1094713353:
-return this.atomicAndIsotopeNumber;
+return this.atomNumberFlags;
 case 1228935687:
 return this.group.chain.model.fileIndex + 1;
 case 1631586315:
@@ -850,7 +850,7 @@ return this.getBondingRadius ();
 case 1111490563:
 return vwr.getNMRCalculation ().getChemicalShift (this);
 case 1111490564:
-return JU.Elements.getCovalentRadius (this.atomicAndIsotopeNumber);
+return JU.Elements.getCovalentRadius (this.atomNumberFlags);
 case 1111490565:
 case 1111490576:
 case 1111490574:
@@ -983,6 +983,8 @@ case 1086324752:
 return this.getCIPChirality (true);
 case 1086324753:
 return this.getCIPChiralityRule ();
+case 1086324754:
+return this.getWyckoffPosition ();
 case 1086324744:
 return this.getGroup1 ('?');
 case 1086324747:
@@ -1019,10 +1021,23 @@ return this.getSymmetryOperatorList (true);
 }
 return "";
 }, "JV.Viewer,~N");
+Clazz.defineMethod (c$, "getWyckoffPosition", 
+function () {
+var ms = this.group.chain.model.ms;
+var a = ms.getBasisAtom (this.i, true);
+var id = a.getSeqID ();
+if (id != 0) {
+return "" + String.fromCharCode (id);
+}var sym = this.getUnitCell ();
+var s;
+if (sym == null || (s = sym.getWyckoffPosition (ms.vwr, this)) == null) return "?";
+ms.setAtomSeqID (this.i, 0 + s.charCodeAt (0));
+return s;
+});
 Clazz.overrideMethod (c$, "getCIPChirality", 
 function (doCalculate) {
 var flags = (this.formalChargeAndFlags & 496) >> 4;
-if (flags == 0 && this.atomicAndIsotopeNumber > 1 && doCalculate) {
+if (flags == 0 && this.atomNumberFlags > 1 && doCalculate) {
 flags = this.group.chain.model.ms.getAtomCIPChiralityCode (this);
 this.formalChargeAndFlags |= ((flags == 0 ? 3 : flags) << 4);
 }return JV.JC.getCIPChiralityName (flags);
