@@ -633,7 +633,7 @@ this.atomResnos[atomIndex] = resno;
 this.taintAtom (atomIndex, 15);
 }, "~N,~N");
 Clazz.defineMethod (c$, "setAtomSeqID", 
- function (atomIndex, seqID) {
+function (atomIndex, seqID) {
 if (seqID == this.at[atomIndex].getSeqID ()) return;
 if (this.atomSeqIDs == null) this.atomSeqIDs =  Clazz.newIntArray (this.at.length, 0);
 this.atomSeqIDs[atomIndex] = seqID;
@@ -2063,6 +2063,10 @@ c$.isDeleted = Clazz.defineMethod (c$, "isDeleted",
 function (atom) {
 return (atom == null || atom.isDeleted ());
 }, "JM.Atom");
+Clazz.defineMethod (c$, "getWyckoffPosition", 
+function (iatom) {
+return (iatom < 0 || iatom >= this.ac || JM.AtomCollection.isDeleted (this.at[iatom]) ? "?" : this.at[iatom].getWyckoffPosition ());
+}, "~N");
 c$.$AtomCollection$AtomSorter$ = function () {
 Clazz.pu$h(self.c$);
 c$ = Clazz.decorateAsClass (function () {
