@@ -69,7 +69,7 @@ this.vwr = vwr;
 this.ms =  new JM.ModelSet (vwr, modelSetName);
 var adapter = vwr.getModelAdapter ();
 this.modelSet0 = modelSet0;
-this.merging = (modelSet0 != null && modelSet0.ac > 0);
+this.merging = (modelSet0 != null && (modelSet0.ac > 0 || modelSet0.vwr.getOperativeSymmetry () != null));
 if (this.merging) {
 this.ms.canSkipLoad = false;
 } else {
@@ -512,7 +512,7 @@ addH = isPdbThisModel && this.doAddPDBHydrogens;
 if (this.jbr != null) this.jbr.setHaveHsAlready (false);
 }var group3 = iterAtom.getGroup3 ();
 var chainID = iterAtom.getChainID ();
-this.checkNewGroup (adapter, chainID, group3, iterAtom.getSequenceNumber (), iterAtom.getInsertionCode (), addH, isLegacyHAddition);
+if (this.jbr != null) this.checkNewGroup (adapter, chainID, group3, iterAtom.getSequenceNumber (), iterAtom.getInsertionCode (), addH, isLegacyHAddition);
 var isotope = iterAtom.getElementNumber ();
 if (addH && JU.Elements.getElementNumber (isotope) == 1) this.jbr.setHaveHsAlready (true);
 var name = iterAtom.getAtomName ();
@@ -597,7 +597,6 @@ return atom;
 }, "~B,JU.BS,~N,~N,~S,~N,~N,JU.Lst,~N,~N,JU.P3,~B,~N,~N,~S,JU.V3,~S,~N,~N");
 Clazz.defineMethod (c$, "checkNewGroup", 
  function (adapter, chainID, group3, groupSequenceNumber, groupInsertionCode, addH, isLegacyHAddition) {
-var group3i = (group3 == null ? null : group3.intern ());
 if (chainID != this.currentChainID) {
 this.currentChainID = chainID;
 this.currentChain = this.getOrAllocateChain (this.model, chainID);
@@ -605,7 +604,8 @@ this.currentGroupInsertionCode = '\uFFFF';
 this.currentGroupSequenceNumber = -1;
 this.currentGroup3 = "xxxx";
 this.isNewChain = true;
-}if (groupSequenceNumber != this.currentGroupSequenceNumber || groupInsertionCode != this.currentGroupInsertionCode || group3i !== this.currentGroup3) {
+}var group3i = (group3 == null ? null : group3.intern ());
+if (groupSequenceNumber != this.currentGroupSequenceNumber || groupInsertionCode != this.currentGroupInsertionCode || group3i !== this.currentGroup3) {
 if (this.groupCount > 0 && addH) {
 this.jbr.addImplicitHydrogenAtoms (adapter, this.groupCount - 1, this.isNewChain && !isLegacyHAddition ? 1 : 0);
 this.jbr.setHaveHsAlready (false);
@@ -628,7 +628,7 @@ Clazz.defineMethod (c$, "getOrAllocateChain",
  function (model, chainID) {
 var chain = model.getChain (chainID);
 if (chain != null) return chain;
-if (model.chainCount == model.chains.length) model.chains = JU.AU.doubleLength (model.chains);
+if (model.chainCount == model.chains.length) model.chains = (model.chainCount == 0 ?  new Array (2) : JU.AU.doubleLength (model.chains));
 return model.chains[model.chainCount++] =  new JM.Chain (model, chainID, (chainID == 0 || chainID == 32 ? 0 : ++this.iChain));
 }, "JM.Model,~N");
 Clazz.defineMethod (c$, "iterateOverAllNewBonds", 
@@ -686,10 +686,10 @@ return bond;
 Clazz.defineMethod (c$, "initializeUnitCellAndSymmetry", 
  function () {
 if (this.someModelsAreModulated && this.ms.bsModulated == null) this.ms.bsModulated =  new JU.BS ();
-if (this.someModelsHaveUnitcells) {
+var haveMergeCells = (this.modelSet0 != null && this.modelSet0.unitCells != null);
+if (this.someModelsHaveUnitcells || haveMergeCells) {
 this.ms.unitCells =  new Array (this.ms.mc);
 this.ms.haveUnitCells = true;
-var haveMergeCells = (this.modelSet0 != null && this.modelSet0.unitCells != null);
 for (var i = 0, pt = 0; i < this.ms.mc; i++) {
 if (haveMergeCells && i < this.baseModelCount) {
 this.ms.unitCells[i] = this.modelSet0.unitCells[i];
