@@ -791,12 +791,26 @@ if (col > 0 && col <= len && row <= len) {
 if (this.tok == 11) (this.value).setElement (row - 1, col - 1, JS.SV.fValue ($var));
  else (this.value).setElement (row - 1, col - 1, JS.SV.fValue ($var));
 return;
-}}if (pt1 != 0 && Math.abs (pt1) <= len && $var.tok == 7) {
+}}if (pt1 != 0 && Math.abs (pt1) <= len && (this.tok == 11 && $var.tok == 8 || this.tok == 12 && $var.tok == 9 || $var.tok == 7)) {
+var data;
+switch ($var.tok) {
+default:
+case 7:
 var sv = $var.getList ();
-if (sv.size () == len) {
-var data =  Clazz.newFloatArray (len, 0);
+if (sv.size () != len) return;
+data =  Clazz.newFloatArray (len, 0);
 for (var i = 0; i < len; i++) data[i] = JS.SV.fValue (sv.get (i));
 
+break;
+case 8:
+var p = $var.value;
+data =  Clazz.newFloatArray (-1, [p.x, p.y, p.z]);
+break;
+case 9:
+var p4 = $var.value;
+data =  Clazz.newFloatArray (-1, [p4.x, p4.y, p4.z, p4.w]);
+break;
+}
 if (pt1 > 0) {
 if (this.tok == 11) (this.value).setRowA (pt1 - 1, data);
  else (this.value).setRowA (pt1 - 1, data);
@@ -804,7 +818,7 @@ if (this.tok == 11) (this.value).setRowA (pt1 - 1, data);
 if (this.tok == 11) (this.value).setColumnA (-1 - pt1, data);
  else (this.value).setColumnA (-1 - pt1, data);
 }break;
-}}break;
+}break;
 case 4:
 var str = this.value;
 var pt = str.length;
