@@ -1133,6 +1133,10 @@ break;
 case 134320141:
 case 1275069443:
 break;
+case 1086324754:
+isInt = (tokenValue === "color");
+isString = !isInt;
+break;
 default:
 isInt = JS.T.tokAttr (tok, 1094713344) && !JS.T.tokAttr (tok, 1111490560);
 isString = !isInt && JS.T.tokAttr (tok, 1086324736);
@@ -1299,8 +1303,23 @@ case 1094717448:
 case 1094713349:
 this.errorStr (45, JS.T.nameOf (tok));
 break;
+case 1086324754:
+iv = atom.getWyckoffPosition ().charCodeAt (0);
+switch (iv) {
+case 63:
+iv = 0;
+break;
+case 65:
+iv = 27;
+break;
+default:
+iv = iv & 0x1F;
+break;
+}
+break;
 default:
 iv = atom.atomPropertyInt (tok);
+break;
 }
 switch (minmaxtype) {
 case 32:
