@@ -615,11 +615,11 @@ pt4.scale4 (-1.0);
 return this.addXPt4 (pt4);
 case 11:
 m = JU.M3.newM3 (x2.value);
-m.invert ();
+m.transpose ();
 return this.addXM3 (m);
 case 12:
 m4 = JU.M4.newM4 (x2.value);
-m4.invert ();
+m4.transpose ();
 return this.addXM4 (m4);
 case 10:
 return this.addXBs (JU.BSUtil.copyInvert (x2.value, (Clazz.instanceOf (x2.value, JM.BondSet) ? this.vwr.ms.bondCount : this.vwr.ms.ac)));
@@ -954,9 +954,11 @@ case 7:
 var l = x2.getList ();
 var lnew =  new JU.Lst ();
 for (var i = l.size (); --i >= 0; ) {
-var pt1 = JU.P3.newP (JS.SV.ptValue (l.get (i)));
+var pt1 = JS.SV.ptValue (l.get (i));
+if (pt1 == null) return false;
+pt1 = JU.P3.newP (pt1);
 m3.rotate (pt1);
-lnew.add (pt1);
+lnew.addLast (pt1);
 }
 return this.addXList (lnew);
 }
@@ -1107,6 +1109,16 @@ return this.addXM3 (q.getMatrix ());
 default:
 return this.addXStr ("NaN");
 }
+case 11:
+var mm = x1.value;
+switch (n) {
+case 1:
+return this.addXFloat (mm.m00 + mm.m11 + mm.m22);
+case 2:
+return this.addXFloat (mm.determinant3 ());
+default:
+return false;
+}
 case 12:
 var m4 = x1.value;
 switch (n) {
