@@ -38,14 +38,10 @@ var queue = this.scriptManager.getScriptQueue ();
 if (queue.size () == 0) return false;
 var scriptItem = this.scriptManager.getScriptItem (false, this.startedByCommandThread);
 if (scriptItem == null) return false;
-var script = scriptItem.get (0);
-var statusList = scriptItem.get (1);
-var returnType = scriptItem.get (2);
-var isQuiet = (scriptItem.get (3)).booleanValue ();
 if (JU.Logger.debugging) {
-JU.Logger.debug ("Queue[" + this.pt + "][" + queue.size () + "] scripts; running: " + script);
+JU.Logger.debug ("Queue[" + this.pt + "][" + queue.size () + "] scripts; running: " + scriptItem.get (0));
 }queue.removeItemAt (0);
-this.vwr.evalStringWaitStatusQueued (returnType, script, statusList, isQuiet, true);
+this.scriptManager.runScriptFromThread (scriptItem);
 if (queue.size () == 0) {
 return false;
 }return true;
