@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["JU.P3"], "JS.SpaceGroupFinder", ["JU.BS", "$.Lst", "$.PT", "JS.SpaceGroup", "$.SymmetryOperation", "JU.BSUtil", "$.SimpleUnitCell", "JV.FileManager"], function () {
+Clazz.load (["JU.P3"], "JS.SpaceGroupFinder", ["JU.BS", "$.Lst", "$.PT", "JS.SpaceGroup", "$.Symmetry", "$.SymmetryOperation", "JU.BSUtil", "$.SimpleUnitCell", "JV.FileManager"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.atoms = null;
 this.nAtoms = 0;
@@ -32,6 +32,19 @@ var n = 0;
 var nChecked = 0;
 var scaling = JU.P3.new3 (1, 1, 1);
 var sg = null;
+var setNew = (isAssign && xyzList != null && this.nAtoms == 0 && (uc == null || uc.getSpaceGroup () == null || "P1".equals ((uc.getSpaceGroup ()).getName ())));
+var name;
+var basis;
+if (setNew) {
+sg = JS.SpaceGroup.determineSpaceGroupNA (xyzList, unitCellParams);
+if (sg == null) {
+sg = JS.SpaceGroup.createSpaceGroupN (xyzList);
+}if (sg == null) return null;
+uc = JS.SpaceGroupFinder.createCompatibleUnitCell (sg, unitCellParams);
+basis =  new JU.BS ();
+name = sg.asString ();
+oabc = uc.getUnitCellVectors ();
+} else {
 try {
 if (JS.SpaceGroupFinder.bsOpGroups == null) JS.SpaceGroupFinder.loadData (vwr, this);
 if (xyzList != null) {
@@ -179,15 +192,15 @@ System.out.println (JS.SpaceGroup.nameToGroup.get (JS.SpaceGroupFinder.groupName
 }
 if (n != 1) return null;
 sg = JS.SpaceGroup.nameToGroup.get (JS.SpaceGroupFinder.groupNames[isg]);
-}var name = sg.asString ();
-var basis = JU.BSUtil.copy (bsAtoms);
+}name = sg.asString ();
+basis = JU.BSUtil.copy (bsAtoms);
 for (var i = targets.nextSetBit (0); i >= 0; i = targets.nextSetBit (i + 1)) basis.clear (this.atoms[i].index);
 
 var nb = basis.cardinality ();
 var msg = name + "\nbasis is " + nb + " atom" + (nb == 1 ? "" : "s") + ": " + basis;
 System.out.println (msg);
 if (asString) return msg;
-var map = sg.dumpInfoObj ();
+}var map = sg.dumpInfoObj ();
 System.out.println ("unitcell is " + uc.getUnitCellInfo (true));
 var bs1 = JU.BS.copy (bsPoints0);
 bs1.andNot (targets);
@@ -202,6 +215,42 @@ map.put ("unitcell", oabc);
 if (isAssign) map.put ("sg", sg);
 return map;
 }, "JV.Viewer,JU.BS,~S,~A,J.api.SymmetryInterface,~B,~B");
+c$.createCompatibleUnitCell = Clazz.defineMethod (c$, "createCompatibleUnitCell", 
+ function (sg, params) {
+var sym;
+var n = JU.PT.parseInt (sg.intlTableNumber);
+var isHexGroup = JS.SpaceGroupFinder.isHexagonal (n, null);
+if (n <= 2 || isHexGroup && JS.SpaceGroupFinder.isHexagonal (-1, params)) {
+} else if (isHexGroup) {
+params =  Clazz.newFloatArray (-1, [params[0], params[0], params[2], 90, 90, 120]);
+} else if (n >= 195) {
+params =  Clazz.newFloatArray (-1, [params[0], params[0], params[0], 90, 90, 90]);
+} else if (n >= 75) {
+params =  Clazz.newFloatArray (-1, [params[0], params[0], params[2], 90, 90, 90]);
+} else if (n >= 16) {
+params =  Clazz.newFloatArray (-1, [params[0], params[1], params[2], 90, 90, 90]);
+} else {
+switch (sg.uniqueAxis) {
+case 'a':
+params =  Clazz.newFloatArray (-1, [params[0], params[1], params[1], 90, params[4], params[5]]);
+break;
+case 'b':
+params =  Clazz.newFloatArray (-1, [params[0], params[1], params[0], params[3], 90, params[5]]);
+break;
+case 'c':
+params =  Clazz.newFloatArray (-1, [params[0], params[0], params[0], params[3], params[4], 90]);
+break;
+default:
+break;
+}
+}sym =  new JS.Symmetry ().setUnitCell (params, false);
+sym.setSpaceGroupTo (sg);
+return sym;
+}, "JS.SpaceGroup,~A");
+c$.isHexagonal = Clazz.defineMethod (c$, "isHexagonal", 
+ function (n, params) {
+return (n < 1 ? params[0] == params[1] && params[3] == 90 && params[4] == 90 && params[5] == 120 : n >= 143 && n <= 194);
+}, "~N,~A");
 Clazz.defineMethod (c$, "removeDuplicates", 
  function (bs) {
 for (var i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1)) {
@@ -311,7 +360,7 @@ return null;
 var ops = JU.PT.split (JU.PT.trim (xyzList.trim ().$replace ('&', ';'), ";="), ";");
 for (var j = ops.length; --j >= 0; ) {
 var xyz = ops[j];
-if (xyz == null || xyz.indexOf ("z") < xyz.lastIndexOf (",")) return "?" + ops[j] + "?";
+if (xyz == null) return "?" + ops[j] + "?";
 xyz = JS.SymmetryOperation.getJmolCanonicalXYZ (xyz);
 for (var i = JS.SpaceGroupFinder.opXYZ.length; --i >= 0; ) {
 if (JS.SpaceGroupFinder.opXYZ[i].equals (xyz)) {
@@ -404,7 +453,7 @@ case 3:
 scaling.z = n;
 break;
 }
-uc = vwr.getSymTemp ().getUnitCell (oabc, false, "scaled");
+uc = vwr.getSymTemp ().getUnitCelld (oabc, false, "scaled");
 var f = 0;
 for (var i = bsPoints.nextSetBit (0); i >= 0; i = bsPoints.nextSetBit (i + 1)) {
 switch (abc) {
