@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["J.api.SymmetryInterface"], "JS.Symmetry", ["JU.BS", "$.Lst", "$.P3", "$.PT", "J.api.Interface", "J.bspt.Bspt", "JS.PointGroup", "$.SpaceGroup", "$.SymmetryInfo", "$.SymmetryOperation", "$.UnitCell", "JU.Escape", "$.Logger", "$.SimpleUnitCell"], function () {
+Clazz.load (["J.api.SymmetryInterface"], "JS.Symmetry", ["JU.BS", "$.Lst", "$.M4", "$.P3", "$.PT", "J.api.Interface", "J.bspt.Bspt", "JS.PointGroup", "$.SpaceGroup", "$.SymmetryInfo", "$.SymmetryOperation", "$.UnitCell", "JU.Escape", "$.Logger", "$.SimpleUnitCell"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.spaceGroup = null;
 this.pointGroup = null;
@@ -141,7 +141,7 @@ return s;
 }, "~S,JU.Matrix,JU.Matrix,JU.Matrix");
 Clazz.overrideMethod (c$, "getMatrixFromString", 
 function (xyz, rotTransMatrix, allowScaling, modDim) {
-return JS.SymmetryOperation.getMatrixFromString (null, xyz, rotTransMatrix, allowScaling);
+return JS.SymmetryOperation.getMatrixFromString (null, xyz, rotTransMatrix, allowScaling, true);
 }, "~S,~A,~B,~N");
 Clazz.overrideMethod (c$, "getSpaceGroupName", 
 function () {
@@ -155,10 +155,6 @@ Clazz.overrideMethod (c$, "setSpaceGroupName",
 function (name) {
 if (this.spaceGroup != null) this.spaceGroup.setName (name);
 }, "~S");
-Clazz.overrideMethod (c$, "getSpaceGroupOperationCount", 
-function () {
-return (this.symmetryInfo != null && this.symmetryInfo.symmetryOperations != null ? this.symmetryInfo.symmetryOperations.length : this.spaceGroup != null && this.spaceGroup.finalOperations != null ? this.spaceGroup.finalOperations.length : 0);
-});
 Clazz.overrideMethod (c$, "getLatticeType", 
 function () {
 return (this.symmetryInfo != null ? this.symmetryInfo.latticeType : this.spaceGroup == null ? 'P' : this.spaceGroup.latticeType);
@@ -167,6 +163,10 @@ Clazz.overrideMethod (c$, "getIntTableNumber",
 function () {
 return (this.symmetryInfo != null ? this.symmetryInfo.intlTableNo : this.spaceGroup == null ? null : this.spaceGroup.intlTableNumber);
 });
+Clazz.overrideMethod (c$, "getIntTableNumberFull", 
+function () {
+return (this.symmetryInfo != null ? this.symmetryInfo.intlTableNoFull : this.spaceGroup == null ? null : this.spaceGroup.intlTableNumberFull != null ? this.spaceGroup.intlTableNumberFull : this.spaceGroup.intlTableNumber);
+});
 Clazz.overrideMethod (c$, "getCoordinatesAreFractional", 
 function () {
 return this.symmetryInfo == null || this.symmetryInfo.coordinatesAreFractional;
@@ -183,6 +183,10 @@ this.symmetryInfo =  new JS.SymmetryInfo ();
 this.symmetryInfo.setSymmetryInfo (null, this.getUnitCellParams (), this.spaceGroup);
 return this.symmetryInfo.infoStr;
 });
+Clazz.overrideMethod (c$, "getSpaceGroupOperationCount", 
+function () {
+return (this.symmetryInfo != null && this.symmetryInfo.symmetryOperations != null ? this.symmetryInfo.symmetryOperations.length : this.spaceGroup != null && this.spaceGroup.finalOperations != null ? this.spaceGroup.finalOperations.length : 0);
+});
 Clazz.overrideMethod (c$, "getSymmetryOperations", 
 function () {
 if (this.symmetryInfo != null) return this.symmetryInfo.symmetryOperations;
@@ -190,6 +194,16 @@ if (this.spaceGroup == null) this.spaceGroup = JS.SpaceGroup.getNull (true, fals
 this.spaceGroup.setFinalOperations ();
 return this.spaceGroup.finalOperations;
 });
+Clazz.overrideMethod (c$, "getAdditionalOperationsCount", 
+function () {
+return (this.symmetryInfo != null && this.symmetryInfo.symmetryOperations != null && this.symmetryInfo.getAdditionalOperations () != null ? this.symmetryInfo.additionalOperations.length : this.spaceGroup != null && this.spaceGroup.finalOperations != null ? this.spaceGroup.getAdditionalOperationsCount () : 0);
+});
+Clazz.overrideMethod (c$, "getAdditionalOperations", 
+function () {
+if (this.symmetryInfo != null) return this.symmetryInfo.getAdditionalOperations ();
+this.getSymmetryOperations ();
+return this.spaceGroup.getAdditionalOperations ();
+});
 Clazz.overrideMethod (c$, "isSimple", 
 function () {
 return (this.spaceGroup == null && (this.symmetryInfo == null || this.symmetryInfo.symmetryOperations == null));
@@ -214,6 +228,7 @@ return (this.unitCell != null);
 });
 Clazz.defineMethod (c$, "setUnitCell", 
 function (unitCellParams, setRelative) {
+if (unitCellParams == null) unitCellParams =  Clazz.newFloatArray (-1, [1, 1, 1, 90, 90, 90]);
 this.unitCell = JS.UnitCell.fromParams (unitCellParams, setRelative);
 return this;
 }, "~A,~B");
@@ -263,8 +278,8 @@ function (m) {
 if (!this.$isBio) this.unitCell.toFractionalM (m);
 }, "JU.M4");
 Clazz.overrideMethod (c$, "toCartesian", 
-function (fpt, ignoreOffset) {
-if (!this.$isBio) this.unitCell.toCartesian (fpt, ignoreOffset);
+function (pt, ignoreOffset) {
+if (!this.$isBio) this.unitCell.toCartesian (pt, ignoreOffset);
 }, "JU.T3,~B");
 Clazz.overrideMethod (c$, "getUnitCellParams", 
 function () {
@@ -349,6 +364,13 @@ this.unitCell = JS.UnitCell.fromOABC (oabc, setRelative);
 if (name != null) this.unitCell.name = name;
 return this;
 }, "~A,~B,~S");
+Clazz.overrideMethod (c$, "getUnitCelld", 
+function (oabc, setRelative, name) {
+if (oabc == null) return null;
+this.unitCell = JS.UnitCell.fromOABC (oabc, setRelative);
+if (name != null) this.unitCell.name = name;
+return this;
+}, "~A,~B,~S");
 Clazz.overrideMethod (c$, "isSupercell", 
 function () {
 return this.unitCell.isSupercell ();
@@ -441,9 +463,9 @@ var loadUC = false;
 if (pt != null && (pt.x != 0 || pt.y != 0 || pt.z != 0)) {
 commands.append ("; set unitcell ").append (JU.Escape.eP (pt));
 loadUC = true;
-}pt = this.getUnitCellMultiplier ();
-if (pt != null) {
-commands.append ("; set unitcell ").append (JU.SimpleUnitCell.escapeMultiplier (pt));
+}var ptm = this.getUnitCellMultiplier ();
+if (ptm != null) {
+commands.append ("; set unitcell ").append (JU.SimpleUnitCell.escapeMultiplier (ptm));
 loadUC = true;
 }var isAssigned = (ms.getInfo (modelIndex, "spaceGroupAssigned") != null);
 var sg = ms.getInfo (modelIndex, "spaceGroup");
@@ -463,27 +485,27 @@ if (this.unitCell == null) this.unitCell = JS.UnitCell.fromOABC (oabc, false);
 return this.unitCell.toFromPrimitive (toPrimitive, type, oabc, primitiveToCrystal);
 }, "~B,~S,~A,JU.M3");
 Clazz.overrideMethod (c$, "generateCrystalClass", 
-function (pt0) {
+function (pt00) {
 var ops = this.getSymmetryOperations ();
 var lst =  new JU.Lst ();
-var isRandom = (pt0 == null);
+var isRandom = (pt00 == null);
 var rand1 = 0;
 var rand2 = 0;
 var rand3 = 0;
+var pt0;
 if (isRandom) {
 rand1 = 2.718281828459045;
 rand2 = 3.141592653589793;
 rand3 = Math.log10 (2000);
 pt0 = JU.P3.new3 (rand1 + 1, rand2 + 2, rand3 + 3);
 } else {
-pt0 = JU.P3.newP (pt0);
+pt0 = JU.P3.newP (pt00);
 }if (ops == null || this.unitCell == null) {
 lst.addLast (pt0);
 } else {
 this.unitCell.toFractional (pt0, true);
 var pt1 = null;
 var pt2 = null;
-var pt3 = null;
 if (isRandom) {
 pt1 = JU.P3.new3 (rand2 + 4, rand3 + 5, rand1 + 6);
 this.unitCell.toFractional (pt1, true);
@@ -501,13 +523,11 @@ lst.addLast (ptNew);
 bspt.addTuple (ptNew);
 if (isRandom) {
 if (pt2 != null) {
-pt3 =  new JU.P3 ();
-ops[i].rotate2 (pt2, pt3);
-lst.addLast (pt3);
+ops[i].rotate2 (pt2, pt);
+lst.addLast (JU.P3.newP (pt));
 }if (pt1 != null) {
-pt3 =  new JU.P3 ();
-ops[i].rotate2 (pt1, pt3);
-lst.addLast (pt3);
+ops[i].rotate2 (pt1, pt);
+lst.addLast (JU.P3.newP (pt));
 }}}
 for (var j = lst.size (); --j >= 0; ) this.unitCell.toCartesian (lst.get (j), true);
 
@@ -652,6 +672,28 @@ ret[k++] = i + 1;
 }}
 return ret;
 }, "JU.P3,~A");
+Clazz.overrideMethod (c$, "getWyckoffPosition", 
+function (vwr, p) {
+if (this.unitCell == null) return "";
+var sg = this.spaceGroup;
+if (sg == null && this.symmetryInfo != null) {
+sg = JS.SpaceGroup.determineSpaceGroupN (this.symmetryInfo.sgName);
+if (sg == null) sg = JS.SpaceGroup.getSpaceGroupFromITAName (this.symmetryInfo.intlTableNoFull);
+if (sg == null) return "?";
+}this.unitCell.toFractional (p = JU.P3.newP (p), true);
+if (JS.Symmetry.wyckoffFinder == null) {
+JS.Symmetry.wyckoffFinder = J.api.Interface.getInterface ("JS.WyckoffFinder", null, "symmetry");
+}try {
+return JS.Symmetry.wyckoffFinder.getWyckoffFinder (vwr, sg.intlTableNumberFull).getWyckoffPosition (p);
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+e.printStackTrace ();
+return "?";
+} else {
+throw e;
+}
+}
+}, "JV.Viewer,JU.P3");
 Clazz.overrideMethod (c$, "getTransform", 
 function (fracA, fracB, best) {
 return this.getDesc (null).getTransform (this.unitCell, this.getSymmetryOperations (), fracA, fracB, best);
@@ -662,13 +704,25 @@ m.rotTrans2 (atom1, atom2);
 atom2.add3 (x, y, z);
 }, "JU.M4,JU.P3,~N,~N,~N,JU.P3");
 Clazz.overrideMethod (c$, "isWithinUnitCell", 
-function (pt, a, b, c) {
-return this.unitCell.isWithinUnitCell (a, b, c, pt);
+function (pt, x, y, z) {
+return this.unitCell.isWithinUnitCell (x, y, z, pt);
 }, "JU.P3,~N,~N,~N");
 Clazz.overrideMethod (c$, "checkPeriodic", 
 function (pt) {
 return this.unitCell.checkPeriodic (pt);
 }, "JU.P3");
+Clazz.overrideMethod (c$, "convertOperation", 
+function (xyz, matrix) {
+if (matrix == null) {
+var a =  Clazz.newFloatArray (16, 0);
+JS.SymmetryOperation.getMatrixFromString (null, xyz, a, true, false);
+a[3] /= 12;
+a[7] /= 12;
+a[11] /= 12;
+return JU.M4.newA16 (a);
+}return JS.SymmetryOperation.getXYZFromMatrixFrac (matrix, false, false, false, true);
+}, "~S,JU.M4");
 Clazz.defineStatics (c$,
+"wyckoffFinder", null,
 "nullDesc", null);
 });
