@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["JU.P3", "$.V3"], "JS.SymmetryDesc", ["java.lang.Float", "java.util.Hashtable", "JU.BS", "$.Lst", "$.M4", "$.Measure", "$.P4", "$.PT", "$.Quat", "$.SB", "JM.Atom", "JS.T", "JS.SpaceGroup", "$.Symmetry", "$.SymmetryOperation", "JU.Escape", "$.Logger"], function () {
+Clazz.load (["JU.P3", "$.V3"], "JS.SymmetryDesc", ["java.lang.Boolean", "$.Float", "java.util.Hashtable", "JU.BS", "$.Lst", "$.M4", "$.Measure", "$.P4", "$.PT", "$.Quat", "$.SB", "JM.Atom", "JS.T", "JS.SpaceGroup", "$.Symmetry", "$.SymmetryOperation", "JU.Escape", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.modelSet = null;
 Clazz.instantialize (this, arguments);
@@ -39,7 +39,7 @@ c$.nullReturn = Clazz.defineMethod (c$, "nullReturn",
  function (type) {
 switch (type) {
 case 135176:
-return "draw ID sym_* delete";
+return ";draw ID sym_* delete;";
 case 1073741961:
 case 1825200146:
 case 1073741974:
@@ -203,7 +203,7 @@ break;
 return bsInfo;
 }, "~N");
 Clazz.defineMethod (c$, "createInfoArray", 
- function (op, uc, ptFrom, ptTarget, id, scaleFactor, options, haveTranslation, bsInfo) {
+ function (op, uc, ptFrom, ptTarget, id, scaleFactor, options, haveTranslation, bsInfo, isSpaceGroup, isAll) {
 if (!op.isFinalized) op.doFinalize ();
 var matrixOnly = (bsInfo.cardinality () == 1 && bsInfo.get (10));
 var isTimeReversed = (op.timeReversal == -1);
@@ -226,7 +226,20 @@ if (JS.SymmetryDesc.pta01.distanceSquared (JS.SymmetryDesc.pta02) >= 1.96E-6) re
 JS.SymmetryDesc.vtrans.sub (JS.SymmetryDesc.ptemp);
 }var m2 = JU.M4.newM4 (op);
 m2.add (JS.SymmetryDesc.vtrans);
-var isMagnetic = (op.timeReversal != 0);
+if (bsInfo.get (10) && ptTarget != null && pta00.equals (ptTarget)) {
+m2.m00 = Math.round (m2.m00);
+m2.m01 = Math.round (m2.m01);
+m2.m02 = Math.round (m2.m02);
+m2.m03 = Math.round (m2.m03);
+m2.m10 = Math.round (m2.m10);
+m2.m11 = Math.round (m2.m11);
+m2.m12 = Math.round (m2.m12);
+m2.m13 = Math.round (m2.m13);
+m2.m20 = Math.round (m2.m20);
+m2.m21 = Math.round (m2.m21);
+m2.m22 = Math.round (m2.m22);
+m2.m23 = Math.round (m2.m23);
+}var isMagnetic = (op.timeReversal != 0);
 if (matrixOnly && !isMagnetic) {
 var im = JS.SymmetryDesc.getKeyType ("matrix");
 var o =  new Array (-im);
@@ -246,18 +259,20 @@ var pt3 = JS.SymmetryDesc.rotTransCart (op, uc, pta03, JS.SymmetryDesc.vtrans);
 var vt1 = JU.V3.newVsub (pt1, pt0);
 var vt2 = JU.V3.newVsub (pt2, pt0);
 var vt3 = JU.V3.newVsub (pt3, pt0);
-JS.SymmetryDesc.approx (JS.SymmetryDesc.vtrans);
+JS.SymmetryOperation.approxPt (JS.SymmetryDesc.vtrans);
 JS.SymmetryDesc.vtemp.cross (vt1, vt2);
 var haveInversion = (JS.SymmetryDesc.vtemp.dot (vt3) < 0);
 if (haveInversion) {
 pt1.sub2 (pt0, vt1);
 pt2.sub2 (pt0, vt2);
 pt3.sub2 (pt0, vt3);
-}var info = JU.Measure.computeHelicalAxis (pta00, pt0, JU.Quat.getQuaternionFrame (pt0, pt1, pt2).div (JU.Quat.getQuaternionFrame (pta00, JS.SymmetryDesc.pta01, JS.SymmetryDesc.pta02)));
-var pa1 = info[0];
-var ax1 = info[1];
+}var q = JU.Quat.getQuaternionFrame (pt0, pt1, pt2).div (JU.Quat.getQuaternionFrame (pta00, JS.SymmetryDesc.pta01, JS.SymmetryDesc.pta02));
+var qF = JU.Quat.new4 (q.q1, q.q2, q.q3, q.q0);
+var info = JU.Measure.computeHelicalAxis (pta00, pt0, qF);
+var pa1 = JU.P3.newP (info[0]);
+var ax1 = JU.P3.newP (info[1]);
 var ang1 = Clazz.floatToInt (Math.abs (JU.PT.approx ((info[3]).x, 1)));
-var pitch1 = JS.SymmetryOperation.approxF ((info[3]).y);
+var pitch1 = JS.SymmetryOperation.approx ((info[3]).y);
 if (haveInversion) {
 pt1.add2 (pt0, vt1);
 pt2.add2 (pt0, vt2);
@@ -309,7 +324,7 @@ trans = null;
 JS.SymmetryDesc.vtemp.normalize ();
 w = -JS.SymmetryDesc.vtemp.x * pa1.x - JS.SymmetryDesc.vtemp.y * pa1.y - JS.SymmetryDesc.vtemp.z * pa1.z;
 plane = JU.P4.new4 (JS.SymmetryDesc.vtemp.x, JS.SymmetryDesc.vtemp.y, JS.SymmetryDesc.vtemp.z, w);
-margin = (Math.abs (w) < 0.01 && JS.SymmetryDesc.vtemp.x * JS.SymmetryDesc.vtemp.y > 0.4 ? 1.30 : 1.05);
+margin = (Math.abs (w) < 0.01 && JS.SymmetryDesc.vtemp.x * JS.SymmetryDesc.vtemp.y > 0.4 ? 1.3 : 1.05);
 isRotation = false;
 haveInversion = false;
 isMirrorPlane = true;
@@ -354,10 +369,13 @@ p0 = pt0;
 ptr.scaleAdd2 (0.5, JS.SymmetryDesc.vtemp, pa1);
 }JS.SymmetryDesc.ptemp.add2 (pa1, JS.SymmetryDesc.vtemp);
 ang2 = Math.round (JU.Measure.computeTorsion (pta00, pa1, JS.SymmetryDesc.ptemp, p0, true));
-if (JS.SymmetryOperation.approxF (ang2) != 0) ang1 = ang2;
+if (JS.SymmetryOperation.approx (ang2) != 0) {
+ang1 = ang2;
 if (ang1 < 0) ang1 = 360 + ang1;
-}var info1 = null;
+}}var info1 = null;
 var type = null;
+var order = op.getOpOrder ();
+var isccw = op.getOpIsCCW ();
 if (bsInfo.get (2) || bsInfo.get (15)) {
 info1 = type = "identity";
 if (isInversionOnly) {
@@ -366,27 +384,28 @@ uc.toFractional (JS.SymmetryDesc.ptemp, false);
 info1 = "Ci: " + JS.SymmetryDesc.strCoord (op, JS.SymmetryDesc.ptemp, op.isBio);
 type = "inversion center";
 } else if (isRotation) {
+var screwtype = (isccw == null ? "" : isccw === Boolean.TRUE ? "(+)" : "(-)");
 if (haveInversion) {
-type = info1 = (Clazz.doubleToInt (360 / ang)) + "-bar axis";
+info1 = (Clazz.doubleToInt (360 / ang)) + "-bar" + screwtype + " axis";
 } else if (pitch1 != 0) {
-type = info1 = (Clazz.doubleToInt (360 / ang)) + "-fold screw axis";
 JS.SymmetryDesc.ptemp.setT (ax1);
 uc.toFractional (JS.SymmetryDesc.ptemp, false);
-info1 += "|translation: " + JS.SymmetryDesc.strCoord (op, JS.SymmetryDesc.ptemp, op.isBio);
+info1 = (Clazz.doubleToInt (360 / ang)) + screwtype + " (" + JS.SymmetryDesc.strCoord (op, JS.SymmetryDesc.ptemp, op.isBio) + ") screw axis";
 } else {
-type = info1 = "C" + (Clazz.doubleToInt (360 / ang)) + " axis";
-}} else if (trans != null) {
+info1 = "C" + (Clazz.doubleToInt (360 / ang)) + screwtype + " axis";
+}type = info1;
+} else if (trans != null) {
 var s = " " + JS.SymmetryDesc.strCoord (op, ftrans, op.isBio);
 if (isTranslation) {
 type = info1 = "translation";
 info1 += ":" + s;
 } else if (isMirrorPlane) {
-var fx = Math.abs (JS.SymmetryOperation.approxF (ftrans.x));
-var fy = Math.abs (JS.SymmetryOperation.approxF (ftrans.y));
-var fz = Math.abs (JS.SymmetryOperation.approxF (ftrans.z));
 s = " " + JS.SymmetryDesc.strCoord (op, ftrans, op.isBio);
+var fx = Math.abs (JS.SymmetryOperation.approx (ftrans.x));
+var fy = Math.abs (JS.SymmetryOperation.approx (ftrans.y));
+var fz = Math.abs (JS.SymmetryOperation.approx (ftrans.z));
 if (fx != 0 && fy != 0 && fz != 0) {
-if (fx == 0.25 && fy == 0.25 && fz == 0.25) {
+if ((fx == 0.25 || fx == 0.75) && (fy == 0.25 || fy == 0.75) && (fz == 0.25 || fz == 0.75)) {
 info1 = "d-";
 } else if (fx == 0.5 && fy == 0.5 && fz == 0.5) {
 info1 = "n-";
@@ -416,8 +435,7 @@ info1 += "|inversion center at " + JS.SymmetryDesc.strCoord (op, JS.SymmetryDesc
 }if (isTimeReversed) {
 info1 += "|time-reversed";
 type += " (time-reversed)";
-}}var cmds = null;
-var isOK = true;
+}}var isOK = true;
 var isScrew = (isRotation && !haveInversion && pitch1 != 0);
 if (!isScrew) {
 isOK = JS.SymmetryDesc.checkHandedness (uc, ax1);
@@ -425,35 +443,53 @@ if (!isOK) {
 ang1 = -ang1;
 if (ang1 < 0) ang1 = 360 + ang1;
 ax1.scale (-1);
-}}if (id != null && bsInfo.get (3)) {
+}}var cmds = null;
+if (id != null && bsInfo.get (3)) {
+if (isSpaceGroup && op.isIrrelevant) {
+cmds = "";
+} else {
 var opType = null;
 var drawid = "\ndraw ID " + id + "_";
 var draw1 =  new JU.SB ();
 draw1.append (drawid).append ("* delete");
+if (!isSpaceGroup) {
 JS.SymmetryDesc.drawLine (draw1, drawid + "frame1X", 0.15, pta00, JS.SymmetryDesc.pta01, "red");
 JS.SymmetryDesc.drawLine (draw1, drawid + "frame1Y", 0.15, pta00, JS.SymmetryDesc.pta02, "green");
 JS.SymmetryDesc.drawLine (draw1, drawid + "frame1Z", 0.15, pta00, pta03, "blue");
-var color;
+}var color;
+var planeCenter = null;
+var nPC = 0;
 var isSpecial = (pta00.distance (pt0) < 0.2);
+var title = (isSpaceGroup ? "<hover>" + info1 + "</hover>" : null);
 if (isRotation) {
-var ptr =  new JU.P3 ();
 color = "red";
 ang = ang1;
 var scale = 1;
 JS.SymmetryDesc.vtemp.setT (ax1);
+if (haveInversion) {
+color = "purple";
+}var wp = "";
+if (isSpaceGroup) {
+pa1.setT (op.getOpPoint ());
+uc.toCartesian (pa1, false);
+}var ptr =  new JU.P3 ();
 if (pitch1 != 0 && !haveInversion) {
 opType = drawid + "screw";
-color = "orange";
+color = (isccw === Boolean.TRUE ? "orange" : isccw === Boolean.FALSE ? "yellow" : order == 4 ? "lightgray" : "grey");
+if (!isSpaceGroup) {
 JS.SymmetryDesc.drawLine (draw1, drawid + "rotLine1", 0.1, pta00, pa1, "red");
 JS.SymmetryDesc.ptemp.add2 (pa1, JS.SymmetryDesc.vtemp);
 JS.SymmetryDesc.drawLine (draw1, drawid + "rotLine2", 0.1, pt0, JS.SymmetryDesc.ptemp, "red");
 ptr.scaleAdd2 (0.5, JS.SymmetryDesc.vtemp, pa1);
-} else {
+}} else {
 ptr.setT (pa1);
 if (!isOK) {
-if (!isSpecial) pa1.sub2 (pa1, JS.SymmetryDesc.vtemp);
+if (!isSpecial && !isSpaceGroup) pa1.sub2 (pa1, JS.SymmetryDesc.vtemp);
 }if (haveInversion) {
 opType = drawid + "rotinv";
+if (isSpaceGroup) {
+JS.SymmetryDesc.vtemp.normalize ();
+} else {
 if (pitch1 == 0) {
 ptr.setT (ipt);
 JS.SymmetryDesc.vtemp.scale (3 * scaleFactor);
@@ -471,58 +507,102 @@ if (!isSpecial) {
 scale = pta00.distance (ptr);
 JS.SymmetryDesc.drawLine (draw1, drawid + "rotLine1", 0.1, pta00, ptr, "red");
 JS.SymmetryDesc.drawLine (draw1, drawid + "rotLine2", 0.1, ptinv, ptr, "red");
-}}} else {
+}}}} else {
 opType = drawid + "rot";
 JS.SymmetryDesc.vtemp.scale (3 * scaleFactor);
 if (isSpecial) {
 } else {
+if (!isSpaceGroup) {
 JS.SymmetryDesc.drawLine (draw1, drawid + "rotLine1", 0.1, pta00, ptr, "red");
 JS.SymmetryDesc.drawLine (draw1, drawid + "rotLine2", 0.1, pt0, ptr, "red");
-}ptr.setT (pa1);
+}}ptr.setT (pa1);
 if (pitch1 == 0 && isSpecial) ptr.scaleAdd2 (0.25, JS.SymmetryDesc.vtemp, ptr);
-}}JS.SymmetryDesc.ptemp.add2 (ptr, JS.SymmetryDesc.vtemp);
+}}if (!isSpaceGroup) {
+JS.SymmetryDesc.ptemp.add2 (ptr, JS.SymmetryDesc.vtemp);
 draw1.append (drawid).append ("rotRotArrow arrow width 0.1 scale " + JU.PT.escF (scale) + " arc ").append (JU.Escape.eP (ptr)).append (JU.Escape.eP (JS.SymmetryDesc.ptemp));
 JS.SymmetryDesc.ptemp.setT (pta00);
 if (JS.SymmetryDesc.ptemp.distance (pt0) < 0.1) JS.SymmetryDesc.ptemp.set (Math.random (), Math.random (), Math.random ());
 draw1.append (JU.Escape.eP (JS.SymmetryDesc.ptemp));
 JS.SymmetryDesc.ptemp.set (0, ang - 5 * Math.signum (ang), 0);
 draw1.append (JU.Escape.eP (JS.SymmetryDesc.ptemp)).append (" color red");
+}var p2 = null;
 if (pitch1 == 0 && !haveInversion) {
 JS.SymmetryDesc.ptemp.scaleAdd2 (0.5, JS.SymmetryDesc.vtemp, pa1);
-pa1.scaleAdd2 (-0.45, JS.SymmetryDesc.vtemp, pa1);
-}JS.SymmetryDesc.drawVector (draw1, drawid, "rotVector1", "vector", "0.1", pa1, JS.SymmetryDesc.vtemp, isTimeReversed ? "gray" : color);
-} else if (isMirrorPlane) {
+pa1.scaleAdd2 (isSpaceGroup ? -0.5 : -0.45, JS.SymmetryDesc.vtemp, pa1);
+if (isSpaceGroup && isAll && (p2 = op.getOpPoint2 ()) != null) {
+ptr.setT (p2);
+uc.toCartesian (ptr, false);
+ptr.scaleAdd2 (-0.5, JS.SymmetryDesc.vtemp, ptr);
+}} else if (isSpaceGroup && isAll && pitch1 != 0 && !haveInversion && isccw == null) {
+p2 = JU.P3.newP (pa1);
+p2.add (JS.SymmetryDesc.vtemp);
+ptr.scaleAdd2 (1.5, JS.SymmetryDesc.vtemp, pa1);
+uc.toFractional (ptr, false);
+if (JS.SymmetryOperation.checkOpPoint (JS.SymmetryOperation.opClean (ptr))) ptr.setT (p2);
+ else p2 = null;
+} else if (haveInversion && isSpaceGroup && isAll) {
+p2 = pt1;
+JS.SymmetryDesc.vtemp.scale (-1);
+}if (pitch1 > 0) {
+wp = "" + (90 - Clazz.floatToInt (JS.SymmetryDesc.vtemp.length () / pitch1 * 90));
+}var name = opType + order + "rotVector1";
+JS.SymmetryDesc.drawVector (draw1, drawid, name, "vector", "0.1" + wp, pa1, JS.SymmetryDesc.vtemp, isTimeReversed ? "gray" : color, title);
+if (p2 != null) {
+JS.SymmetryDesc.drawVector (draw1, drawid, name + "b", "vector", "0.1" + wp, ptr, JS.SymmetryDesc.vtemp, isTimeReversed ? "gray" : color, title);
+}} else if (isMirrorPlane) {
 JS.SymmetryDesc.ptemp.sub2 (ptref, pta00);
-if (pta00.distance (ptref) > 0.2) JS.SymmetryDesc.drawVector (draw1, drawid, "planeVector", "vector", "0.05", pta00, JS.SymmetryDesc.ptemp, isTimeReversed ? "gray" : "cyan");
+if (!isSpaceGroup && pta00.distance (ptref) > 0.2) JS.SymmetryDesc.drawVector (draw1, drawid, "planeVector", "vector", "0.05", pta00, JS.SymmetryDesc.ptemp, isTimeReversed ? "gray" : "cyan", null);
 opType = drawid + "plane";
-if (trans != null) {
+var p = JU.P4.newPt (plane);
+if (trans == null) {
+color = "green";
+} else {
 opType = drawid + "glide";
+color = "blue";
+p.w += 0.01;
+if (!isSpaceGroup) {
 JS.SymmetryDesc.drawFrameLine ("X", ptref, vt1, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "red");
 JS.SymmetryDesc.drawFrameLine ("Y", ptref, vt2, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "green");
 JS.SymmetryDesc.drawFrameLine ("Z", ptref, vt3, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "blue");
-}color = (trans == null ? "green" : "blue");
-var v = this.modelSet.vwr.getTriangulator ().intersectPlane (plane, uc.getCanonicalCopy (margin, true), 3);
-if (v != null) for (var i = v.size (); --i >= 0; ) {
+}}var v = this.modelSet.vwr.getTriangulator ().intersectPlane (p, uc.getCanonicalCopy (margin, true), 3);
+if (v != null) {
+var isCoincident = (isSpaceGroup && op.isCoincident);
+planeCenter =  new JU.P3 ();
+for (var i = v.size (); --i >= 0; ) {
 var pts = v.get (i);
-draw1.append (drawid).append ("planep").appendI (i).append (" ").append (JU.Escape.eP (pts[0])).append (JU.Escape.eP (pts[1]));
-if (pts.length == 3) draw1.append (JU.Escape.eP (pts[2]));
-draw1.append (" color translucent ").append (color);
+draw1.append (drawid).append (trans == null ? "m" : "g").append ("planep").appendI (i).append (" ").append (JU.Escape.eP (pts[0])).append (JU.Escape.eP (pts[1]));
+if (pts.length == 3) {
+if (isCoincident) {
+if ((i % 2 == 0) == (trans == null)) {
+if (title != null) draw1.append (" ").append (JU.PT.esc (title));
+continue;
+}}draw1.append (JU.Escape.eP (pts[2]));
+} else {
+planeCenter.add (pts[0]);
+planeCenter.add (pts[1]);
+nPC += 2;
+}draw1.append (" color translucent ").append (color);
+if (title != null) draw1.append (" ").append (JU.PT.esc (title));
 }
-if (v == null || v.size () == 0) {
+}if (v == null || v.size () == 0) {
 JS.SymmetryDesc.ptemp.add2 (pa1, ax1);
 draw1.append (drawid).append ("planeCircle scale 2.0 circle ").append (JU.Escape.eP (pa1)).append (JU.Escape.eP (JS.SymmetryDesc.ptemp)).append (" color translucent ").append (color).append (" mesh fill");
+if (title != null) draw1.append (" ").append (JU.PT.esc (title));
 }}if (haveInversion) {
 opType = drawid + "inv";
 draw1.append (drawid).append ("invPoint diameter 0.4 ").append (JU.Escape.eP (ipt));
+if (title != null) draw1.append (" ").append (JU.PT.esc (title));
 if (isInversionOnly) {
 JS.SymmetryDesc.ptemp.sub2 (ptinv, pta00);
-JS.SymmetryDesc.drawVector (draw1, drawid, "invArrow", "vector", "0.05", pta00, JS.SymmetryDesc.ptemp, isTimeReversed ? "gray" : "cyan");
-} else {
+if (!isSpaceGroup) {
+JS.SymmetryDesc.drawVector (draw1, drawid, "invArrow", "vector", "0.05", pta00, JS.SymmetryDesc.ptemp, isTimeReversed ? "gray" : "cyan", null);
+}} else {
+if (!isSpaceGroup) {
 draw1.append (" color cyan");
 if (!isSpecial) {
 JS.SymmetryDesc.ptemp.sub2 (pt0, ptinv);
-JS.SymmetryDesc.drawVector (draw1, drawid, "invArrow", "vector", "0.05", ptinv, JS.SymmetryDesc.ptemp, isTimeReversed ? "gray" : "cyan");
-}if (options != 1073742066) {
+JS.SymmetryDesc.drawVector (draw1, drawid, "invArrow", "vector", "0.05", ptinv, JS.SymmetryDesc.ptemp, isTimeReversed ? "gray" : "cyan", null);
+}if (options != 1073742066 && !isSpaceGroup) {
 JS.SymmetryDesc.vtemp.setT (vt1);
 JS.SymmetryDesc.vtemp.scale (-1);
 JS.SymmetryDesc.drawFrameLine ("X", ptinv, JS.SymmetryDesc.vtemp, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "red");
@@ -532,10 +612,16 @@ JS.SymmetryDesc.drawFrameLine ("Y", ptinv, JS.SymmetryDesc.vtemp, 0.15, JS.Symme
 JS.SymmetryDesc.vtemp.setT (vt3);
 JS.SymmetryDesc.vtemp.scale (-1);
 JS.SymmetryDesc.drawFrameLine ("Z", ptinv, JS.SymmetryDesc.vtemp, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "blue");
-}}}if (trans != null) {
-if (ptref == null) ptref = JU.P3.newP (pta00);
-JS.SymmetryDesc.drawVector (draw1, drawid, "transVector", "vector", (isTranslationOnly ? "0.1" : "0.05"), ptref, trans, isTimeReversed && !haveInversion && !isMirrorPlane && !isRotation ? "darkGray" : "gold");
-}JS.SymmetryDesc.ptemp2.setT (pt0);
+}}}}if (trans != null) {
+if (isMirrorPlane && isSpaceGroup) {
+ptref = planeCenter;
+ptref.scale (1 / nPC);
+ptref.scaleAdd2 (-0.5, trans, ptref);
+} else if (ptref == null) {
+ptref = (isSpaceGroup ?  new JU.P3 () : JU.P3.newP (pta00));
+}JS.SymmetryDesc.drawVector (draw1, drawid, "transVector", "vector", (isTranslationOnly ? "0.1" : "0.05"), ptref, trans, isTimeReversed && !haveInversion && !isMirrorPlane && !isRotation ? "darkGray" : "gold", title);
+}if (!isSpaceGroup) {
+JS.SymmetryDesc.ptemp2.setT (pt0);
 JS.SymmetryDesc.ptemp.sub2 (pt1, pt0);
 JS.SymmetryDesc.ptemp.scaleAdd2 (0.9, JS.SymmetryDesc.ptemp, JS.SymmetryDesc.ptemp2);
 JS.SymmetryDesc.drawLine (draw1, drawid + "frame2X", 0.2, JS.SymmetryDesc.ptemp2, JS.SymmetryDesc.ptemp, "red");
@@ -558,12 +644,12 @@ draw1.append (drawid).append ("offsetFrameX diameter 0.20 @{set2.xyz} @{set2.xyz
 draw1.append (drawid).append ("offsetFrameY diameter 0.20 @{set2.xyz} @{set2.xyz + ").append (JU.Escape.eP (vt2)).append ("*0.9} color green");
 draw1.append (drawid).append ("offsetFrameZ diameter 0.20 @{set2.xyz} @{set2.xyz + ").append (JU.Escape.eP (vt3)).append ("*0.9} color purple");
 }draw1.append ("\n}\n");
-cmds = draw1.toString ();
+}cmds = draw1.toString ();
 if (JU.Logger.debugging) JU.Logger.info (cmds);
 draw1 = null;
 drawid = null;
-}if (trans == null) ftrans = null;
-if (isRotation && !haveInversion && pitch1 != 0) {
+}}if (trans == null) ftrans = null;
+if (isScrew) {
 trans = JU.V3.newV (ax1);
 JS.SymmetryDesc.ptemp.setT (trans);
 uc.toFractional (JS.SymmetryDesc.ptemp, false);
@@ -660,7 +746,7 @@ case 17:
 var cift = null;
 if (!op.isBio && !xyzNew.equals (op.xyzOriginal)) {
 if (op.number > 0) {
-var orig = JS.SymmetryOperation.getMatrixFromXYZ (op.xyzOriginal);
+var orig = JS.SymmetryOperation.getMatrixFromXYZ (op.xyzOriginal, false);
 orig.sub (m2);
 cift =  new JU.P3 ();
 orig.getTranslation (cift);
@@ -673,7 +759,7 @@ break;
 }
 }
 return ret;
-}, "JS.SymmetryOperation,J.api.SymmetryInterface,JU.P3,JU.P3,~S,~N,~N,~B,JU.BS");
+}, "JS.SymmetryOperation,J.api.SymmetryInterface,JU.P3,JU.P3,~S,~N,~N,~B,JU.BS,~B,~B");
 c$.checkHandedness = Clazz.defineMethod (c$, "checkHandedness", 
  function (uc, ax1) {
 var a;
@@ -681,15 +767,15 @@ var b;
 var c;
 JS.SymmetryDesc.ptemp.set (1, 0, 0);
 uc.toCartesian (JS.SymmetryDesc.ptemp, false);
-a = JS.SymmetryDesc.approx0f (JS.SymmetryDesc.ptemp.dot (ax1));
+a = JS.SymmetryDesc.approx0d (JS.SymmetryDesc.ptemp.dot (ax1));
 JS.SymmetryDesc.ptemp.set (0, 1, 0);
 uc.toCartesian (JS.SymmetryDesc.ptemp, false);
-b = JS.SymmetryDesc.approx0f (JS.SymmetryDesc.ptemp.dot (ax1));
+b = JS.SymmetryDesc.approx0d (JS.SymmetryDesc.ptemp.dot (ax1));
 JS.SymmetryDesc.ptemp.set (0, 0, 1);
 uc.toCartesian (JS.SymmetryDesc.ptemp, false);
-c = JS.SymmetryDesc.approx0f (JS.SymmetryDesc.ptemp.dot (ax1));
+c = JS.SymmetryDesc.approx0d (JS.SymmetryDesc.ptemp.dot (ax1));
 return (a == 0 ? (b == 0 ? c > 0 : b > 0) : c == 0 ? a > 0 : (b == 0 ? c > 0 : a * b * c > 0));
-}, "J.api.SymmetryInterface,JU.V3");
+}, "J.api.SymmetryInterface,JU.P3");
 c$.drawLine = Clazz.defineMethod (c$, "drawLine", 
  function (s, id, diameter, pt0, pt1, color) {
 s.append (id).append (" diameter ").appendF (diameter).append (JU.Escape.eP (pt0)).append (JU.Escape.eP (pt1)).append (" color ").append (color);
@@ -701,14 +787,15 @@ ptemp.add (v);
 JS.SymmetryDesc.drawLine (draw1, key + "Pt" + xyz, width, pt, ptemp, "translucent " + color);
 }, "~S,JU.P3,JU.V3,~N,JU.P3,JU.SB,~S,~S");
 c$.drawVector = Clazz.defineMethod (c$, "drawVector", 
- function (draw1, drawid, label, type, d, pt1, v, color) {
+ function (draw1, drawid, label, type, d, pt1, v, color, title) {
 if (type.equals ("vline")) {
 JS.SymmetryDesc.ptemp2.add2 (pt1, v);
 type = "";
 v = JS.SymmetryDesc.ptemp2;
 }d += " ";
 draw1.append (drawid).append (label).append (" diameter ").append (d).append (type).append (JU.Escape.eP (pt1)).append (JU.Escape.eP (v)).append (" color ").append (color);
-}, "JU.SB,~S,~S,~S,~S,JU.T3,JU.T3,~S");
+if (title != null) draw1.append (" \"" + title + "\"");
+}, "JU.SB,~S,~S,~S,~S,JU.T3,JU.T3,~S,~S");
 c$.setFractional = Clazz.defineMethod (c$, "setFractional", 
  function (uc, pt00, pt01, offset) {
 pt01.setT (pt00);
@@ -732,25 +819,17 @@ return (isBio ? p.x + " " + p.y + " " + p.z : op.fcoord2 (p));
 c$.approx0 = Clazz.defineMethod (c$, "approx0", 
  function (pt) {
 if (pt != null) {
-pt.x = JS.SymmetryDesc.approx0f (pt.x);
-pt.y = JS.SymmetryDesc.approx0f (pt.y);
-pt.z = JS.SymmetryDesc.approx0f (pt.z);
+pt.x = JS.SymmetryDesc.approx0d (pt.x);
+pt.y = JS.SymmetryDesc.approx0d (pt.y);
+pt.z = JS.SymmetryDesc.approx0d (pt.z);
 }return pt;
 }, "JU.T3");
-c$.approx0f = Clazz.defineMethod (c$, "approx0f", 
+c$.approx0d = Clazz.defineMethod (c$, "approx0d", 
  function (x) {
 return (Math.abs (x) < 0.0001 ? 0 : x);
 }, "~N");
-c$.approx = Clazz.defineMethod (c$, "approx", 
- function (pt) {
-if (pt != null) {
-pt.x = JS.SymmetryOperation.approxF (pt.x);
-pt.y = JS.SymmetryOperation.approxF (pt.y);
-pt.z = JS.SymmetryOperation.approxF (pt.z);
-}return pt;
-}, "JU.T3");
 Clazz.defineMethod (c$, "getSymmetryInfo", 
- function (sym, iModel, iatom, uc, xyz, op, translation, pt, pt2, id, type, scaleFactor, nth, options) {
+ function (iModel, iatom, uc, xyz, op, translation, pt, pt2, id, type, scaleFactor, nth, options, isSpaceGroup) {
 var returnType = 0;
 var nullRet = JS.SymmetryDesc.nullReturn (type);
 switch (type) {
@@ -780,15 +859,18 @@ break;
 break;
 }
 var bsInfo = JS.SymmetryDesc.getInfoBS (returnType);
+var isAll = (nth == -2);
 var iop = op;
 var offset = (options == 1073742066 && (type == 1153433601 || type == 134217751) ? pt2 : null);
 if (offset != null) pt2 = null;
 var info = null;
 var xyzOriginal = null;
+var ops = null;
 if (pt2 == null) {
 if (xyz == null) {
-var ops = uc.getSymmetryOperations ();
-if (ops == null || op == 0 || Math.abs (op) > ops.length) return nullRet;
+ops = (isAll ? uc.getAdditionalOperations () : uc.getSymmetryOperations ());
+if (ops == null || Math.abs (op) > ops.length) return nullRet;
+if (op == 0) return nullRet;
 iop = Math.abs (op) - 1;
 xyz = (translation == null ? ops[iop].xyz : ops[iop].getxyzTrans (translation));
 xyzOriginal = ops[iop].xyzOriginal;
@@ -796,28 +878,30 @@ xyzOriginal = ops[iop].xyzOriginal;
 iop = op = 0;
 }var symTemp =  new JS.Symmetry ();
 symTemp.setSpaceGroup (false);
-var isBio = uc.isBio ();
+var isBio = (uc != null && uc.isBio ());
 var i = (isBio ? symTemp.addBioMoleculeOperation ((uc.getSpaceGroup ()).finalOperations[iop], op < 0) : symTemp.addSpaceGroupOperation ((op < 0 ? "!" : "=") + xyz, Math.abs (op)));
 if (i < 0) return nullRet;
 var opTemp = symTemp.getSpaceGroupOperation (i);
+if (isSpaceGroup) opTemp.isCoincident = ops[iop].isCoincident;
 if (xyzOriginal != null) opTemp.xyzOriginal = xyzOriginal;
 opTemp.number = op;
 if (!isBio) opTemp.getCentering ();
 if (pt == null && iatom >= 0) pt = this.modelSet.at[iatom];
 if (type == 134217751 || type == 1153433601) {
-if (isBio) return nullRet;
+if (isBio || pt == null) return nullRet;
 symTemp.setUnitCell (uc);
-pt = JU.P3.newP (pt);
-uc.toFractional (pt, false);
-if (Float.isNaN (pt.x)) return nullRet;
+JS.SymmetryDesc.ptemp.setT (pt);
+uc.toFractional (JS.SymmetryDesc.ptemp, false);
+if (Float.isNaN (JS.SymmetryDesc.ptemp.x)) return nullRet;
 var sympt =  new JU.P3 ();
-symTemp.newSpaceGroupPoint (pt, i, null, 0, 0, 0, sympt);
+symTemp.newSpaceGroupPoint (JS.SymmetryDesc.ptemp, i, null, 0, 0, 0, sympt);
 if (options == 1073742066) {
 uc.unitize (sympt);
 sympt.add (offset);
 }symTemp.toCartesian (sympt, false);
-return (type == 1153433601 ? this.getAtom (uc, iModel, iatom, sympt) : sympt);
-}info = this.createInfoArray (opTemp, uc, pt, null, (id == null ? "sym" : id), scaleFactor, options, (translation != null), bsInfo);
+var ret = sympt;
+return (type == 1153433601 ? this.getAtom (uc, iModel, iatom, ret) : ret);
+}info = this.createInfoArray (opTemp, uc, pt, null, (id == null ? "sym" : id), scaleFactor, options, (translation != null), bsInfo, isSpaceGroup, isAll);
 if (type == 1275068418 && id != null) {
 returnType = JS.SymmetryDesc.getKeyType (id);
 }} else {
@@ -847,7 +931,7 @@ id = stype = null;
 default:
 if (nth == 0) nth = 1;
 }
-var ret1 = this.getSymopInfoForPoints (sym, iModel, op, translation, pt, pt2, id, stype, scaleFactor, nth, options, bsInfo);
+var ret1 = this.getSymopInfoForPoints (uc, iModel, op, translation, pt, pt2, id, stype, scaleFactor, nth, options, bsInfo);
 if (asString) {
 return ret1;
 }if (Clazz.instanceOf (ret1, String)) return nullRet;
@@ -857,17 +941,17 @@ if (!(Clazz.instanceOf (pt, JM.Atom)) && !(Clazz.instanceOf (pt2, JM.Atom))) iat
 return (info == null ? nullRet : this.getAtom (uc, iModel, iatom, info[7]));
 }}if (info == null) return nullRet;
 var isList = (info.length > 0 && Clazz.instanceOf (info[0], Array));
-if (nth < 0 && op <= 0 && (type == 1275068418 || isList)) {
+if (nth < 0 && op <= 0 && xyz == null && (type == 1275068418 || isList)) {
 if (type == 1275068418 && info.length > 0 && !(Clazz.instanceOf (info[0], Array))) info =  Clazz.newArray (-1, [info]);
 var lst =  new JU.Lst ();
 for (var i = 0; i < info.length; i++) lst.addLast (JS.SymmetryDesc.getInfo (info[i], returnType < 0 ? returnType : type));
 
 return lst;
-} else if (returnType < 0 && (nth >= 0 || op > 0)) {
+} else if (returnType < 0 && (nth >= 0 || op > 0 || xyz != null)) {
 type = returnType;
 }if (nth > 0 && isList) info = info[0];
 return JS.SymmetryDesc.getInfo (info, type);
-}, "J.api.SymmetryInterface,~N,~N,J.api.SymmetryInterface,~S,~N,JU.P3,JU.P3,JU.P3,~S,~N,~N,~N,~N");
+}, "~N,~N,J.api.SymmetryInterface,~S,~N,JU.P3,JU.P3,JU.P3,~S,~N,~N,~N,~N,~B");
 Clazz.defineMethod (c$, "getAtom", 
  function (uc, iModel, iAtom, sympt) {
 var bsElement = null;
@@ -923,27 +1007,30 @@ Clazz.defineMethod (c$, "getSymopInfo",
 function (iAtom, xyz, op, translation, pt, pt2, id, type, scaleFactor, nth, options, opList) {
 if (type == 0) type = JS.SymmetryDesc.getType (id);
 var ret = (type == 1153433601 ?  new JU.BS () : "");
-if (iAtom < 0) return ret;
-var iModel = this.modelSet.at[iAtom].mi;
+var iModel = (iAtom >= 0 ? this.modelSet.at[iAtom].mi : this.modelSet.vwr.am.cmi);
+if (iModel < 0) return ret;
 var uc = this.modelSet.am[iModel].biosymmetry;
-if (uc == null && (uc = this.modelSet.getUnitCell (iModel)) == null) return ret;
-if (type != 135176 || op != 2147483647 && opList == null) {
-return this.getSymmetryInfo (uc, iModel, iAtom, uc, xyz, op, translation, pt, pt2, id, type, scaleFactor, nth, options);
-}var s = "";
-var ops = uc.getSymmetryOperations ();
+if (uc == null && (uc = this.modelSet.getUnitCell (iModel)) == null) {
+uc =  new JS.Symmetry ().setUnitCell (null, false);
+}if (type != 135176 || op != 2147483647 && opList == null) {
+return this.getSymmetryInfo (iModel, iAtom, uc, xyz, op, translation, pt, pt2, id, type, scaleFactor, nth, options, false);
+}if (uc == null) return ret;
+var isSpaceGroup = (xyz == null && nth < 0 && opList == null);
+var s = "";
+var ops = (isSpaceGroup && nth == -2 ? uc.getAdditionalOperations () : uc.getSymmetryOperations ());
 if (ops != null) {
 if (id == null) id = "sg";
 var n = ops.length;
-if (pt != null && pt2 == null) {
+if (pt != null && pt2 == null || opList != null) {
 if (opList == null) opList = uc.getInvariantSymops (pt, null);
 n = opList.length;
 for (var i = 0; i < n; i++) {
 if (nth > 0 && nth != i + 1) continue;
 op = opList[i];
-s += this.getSymmetryInfo (uc, iModel, iAtom, uc, xyz, op, translation, pt, pt2, id + op, 135176, scaleFactor, nth, options);
+s += this.getSymmetryInfo (iModel, iAtom, uc, xyz, op, translation, pt, pt2, id + op, 135176, scaleFactor, nth, options, pt == null);
 }
 } else {
-for (op = 1; op <= n; op++) s += this.getSymmetryInfo (uc, iModel, iAtom, uc, xyz, op, translation, pt, pt2, id + op, 135176, scaleFactor, nth, options);
+for (op = 1; op <= n; op++) s += this.getSymmetryInfo (iModel, iAtom, uc, xyz, op, translation, pt, pt2, id + op, 135176, scaleFactor, nth, options, true);
 
 }}return s;
 }, "~N,~S,~N,JU.P3,JU.P3,JU.P3,~S,~N,~N,~N,~N,~A");
@@ -1004,12 +1091,13 @@ if (op == null) continue;
 op.xyzOriginal = xyzOriginal;
 }if (op.timeReversal != 0 || op.modDim > 0) isStandard = false;
 if (slist != null) slist += ";" + op.xyz;
-var ret = (symOp > 0 && symOp - 1 != iop ? null : this.createInfoArray (op, cellInfo, pt1, pt2, drawID, scaleFactor, options, false, bsInfo));
+var ret = (symOp > 0 && symOp - 1 != iop ? null : this.createInfoArray (op, cellInfo, pt1, pt2, drawID, scaleFactor, options, false, bsInfo, false, false));
 if (ret != null) {
 if (nth > 0 && ++nop != nth) continue;
 infolist[i] = ret;
-if (!matrixOnly) sops += "\n" + (i + 1) + "\t" + ret[bsInfo.get (19) ? 19 : 0] + "\t" + ret[2];
+if (!matrixOnly) sops += "\n" + (i + 1) + "\t" + ret[bsInfo.get (19) ? 19 : 0] + "\t  " + ret[2];
 opCount++;
+if (symOp > 0) break;
 }}
 info.put ("operations", infolist);
 if (!matrixOnly) info.put ("symmetryInfo", (sops.length == 0 ? "" : sops.substring (1)));
@@ -1055,7 +1143,7 @@ uc.unitize (JS.SymmetryDesc.pta01);
 var d = JS.SymmetryDesc.pta01.distanceSquared (JS.SymmetryDesc.pta02);
 if (d < 1.96E-6) {
 JS.SymmetryDesc.vtrans.sub (JS.SymmetryDesc.ptemp);
-uc.normalize (JS.SymmetryDesc.vtrans);
+JS.SymmetryOperation.normalize12ths (JS.SymmetryDesc.vtrans);
 var m2 = JU.M4.newM4 (op);
 m2.add (JS.SymmetryDesc.vtrans);
 JS.SymmetryDesc.pta01.setT (fracA);
