@@ -1,14 +1,16 @@
 Clazz.declarePackage ("JS");
-Clazz.load (null, "JS.SymmetryInfo", ["JU.PT", "JU.SimpleUnitCell"], function () {
+Clazz.load (null, "JS.SymmetryInfo", ["JU.PT", "JS.SpaceGroup", "$.SymmetryOperation", "JU.SimpleUnitCell"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.coordinatesAreFractional = false;
 this.isMultiCell = false;
 this.sgName = null;
 this.symmetryOperations = null;
+this.additionalOperations = null;
 this.infoStr = null;
 this.cellRange = null;
 this.latticeType = 'P';
 this.intlTableNo = null;
+this.intlTableNoFull = null;
 Clazz.instantialize (this, arguments);
 }, JS, "SymmetryInfo");
 Clazz.makeConstructor (c$, 
@@ -22,6 +24,7 @@ this.cellRange = info.get ("unitCellRange");
 this.sgName = info.get ("spaceGroup");
 if (this.sgName == null || this.sgName === "") this.sgName = "spacegroup unspecified";
 this.intlTableNo = info.get ("intlTableNo");
+this.intlTableNoFull = info.get ("intlTableNoFull");
 var s = info.get ("latticeType");
 this.latticeType = (s == null ? 'P' : s.charAt (0));
 symmetryCount = info.containsKey ("symmetryCount") ? (info.get ("symmetryCount")).intValue () : 0;
@@ -32,6 +35,7 @@ this.infoStr = "Spacegroup: " + this.sgName;
 } else {
 this.cellRange = null;
 this.sgName = sg.getName ();
+this.intlTableNoFull = sg.intlTableNumberFull;
 this.intlTableNo = sg.intlTableNumber;
 this.latticeType = sg.latticeType;
 symmetryCount = sg.getOperationCount ();
@@ -58,4 +62,14 @@ this.cellRange = null;
 this.infoStr = "";
 }return unitCellParams;
 }, "java.util.Map,~A,JS.SpaceGroup");
+Clazz.defineMethod (c$, "getAdditionalOperations", 
+function () {
+if (this.additionalOperations == null && this.symmetryOperations != null) {
+this.additionalOperations = JS.SymmetryOperation.getAdditionalOperations (this.symmetryOperations);
+}return this.additionalOperations;
+});
+Clazz.defineMethod (c$, "getSpaceGroupFromOperators", 
+function () {
+return JS.SpaceGroup.determineSpaceGroupN (this.sgName);
+});
 });
