@@ -514,9 +514,9 @@ var n = list.size ();
 for (var i = 0, nops = ops.length; i < nops; i++) {
 var p = JU.P3.newP (pf);
 ops[i].rotTrans (p);
-p.x = (p.x - Math.floor (p.x));
-p.y = (p.y - Math.floor (p.y));
-p.z = (p.z - Math.floor (p.z));
+p.x = this.fixFloor (p.x - Math.floor (p.x));
+p.y = this.fixFloor (p.y - Math.floor (p.y));
+p.z = this.fixFloor (p.z - Math.floor (p.z));
 list.addLast (p);
 n++;
 }
@@ -552,6 +552,10 @@ for (var i = list.size (); --i >= n0; ) this.toCartesian (list.get (i), true);
 
 }return list;
 }, "JU.P3,~S,~A,JU.Lst,~N,~N");
+Clazz.defineMethod (c$, "fixFloor", 
+ function (d) {
+return (d == 1 ? 0 : d);
+}, "~N");
 c$.checkDuplicate = Clazz.defineMethod (c$, "checkDuplicate", 
  function (list, i0, n0, n) {
 if (n < 0) n = list.size ();
@@ -565,12 +569,6 @@ j--;
 }}
 }
 }, "JU.Lst,~N,~N,~N");
-Clazz.defineMethod (c$, "normalize", 
-function (vtrans) {
-vtrans.x = JU.SimpleUnitCell.normalizeXRnd (vtrans.x);
-vtrans.y = JU.SimpleUnitCell.normalizeXRnd (vtrans.y);
-vtrans.z = JU.SimpleUnitCell.normalizeXRnd (vtrans.z);
-}, "JU.V3");
 Clazz.defineMethod (c$, "getState", 
 function () {
 var s = "";
