@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JU");
-Clazz.load (["JU.P3", "$.V3"], "JU.BoxInfo", ["java.lang.Double", "java.util.HashMap", "JU.Point3fi"], function () {
+Clazz.load (["JU.P3", "$.V3"], "JU.BoxInfo", ["java.lang.Double", "java.util.HashMap", "JU.Measure", "$.P4", "JU.Point3fi"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.bbCorner0 = null;
 this.bbCorner1 = null;
@@ -204,6 +204,23 @@ Clazz.overrideMethod (c$, "toString",
 function () {
 return "" + this.bbCorner0 + this.bbCorner1;
 });
+c$.getBoxFacesFromOABC = Clazz.defineMethod (c$, "getBoxFacesFromOABC", 
+function (oabc) {
+var faces =  new Array (6);
+var vNorm =  new JU.V3 ();
+var vAB =  new JU.V3 ();
+var pta =  new JU.P3 ();
+var ptb =  new JU.P3 ();
+var ptc =  new JU.P3 ();
+var vertices = (oabc == null ? JU.BoxInfo.unitCubePoints : JU.BoxInfo.getVerticesFromOABC (oabc));
+for (var i = 0; i < 6; i++) {
+pta.setT (vertices[JU.BoxInfo.facePoints[i][0]]);
+ptb.setT (vertices[JU.BoxInfo.facePoints[i][1]]);
+ptc.setT (vertices[JU.BoxInfo.facePoints[i][2]]);
+faces[i] = JU.Measure.getPlaneThroughPoints (pta, ptb, ptc, vNorm, vAB,  new JU.P4 ());
+}
+return faces;
+}, "~A");
 Clazz.defineStatics (c$,
 "X", 4,
 "Y", 2,
@@ -211,10 +228,11 @@ Clazz.defineStatics (c$,
 "XYZ", 7,
 "bbcageTickEdges",  Clazz.newCharArray (-1, ['z', '\0', '\0', 'y', 'x', '\0', '\0', '\0', '\0', '\0', '\0', '\0']),
 "uccageTickEdges",  Clazz.newCharArray (-1, ['z', 'y', 'x', '\0', '\0', '\0', '\0', '\0', '\0', '\0', '\0', '\0']),
-"edges",  Clazz.newByteArray (-1, [0, 1, 0, 2, 0, 4, 1, 3, 1, 5, 2, 3, 2, 6, 3, 7, 4, 5, 4, 6, 5, 7, 6, 7]));
+"edges",  Clazz.newByteArray (-1, [0, 1, 0, 2, 0, 4, 1, 3, 1, 5, 2, 3, 2, 6, 3, 7, 4, 5, 4, 6, 5, 7, 6, 7]),
+"faceOrder",  Clazz.newIntArray (-1, [0, 3, 5, 2, 1, 4]),
+"facePoints",  Clazz.newArray (-1, [ Clazz.newIntArray (-1, [4, 0, 6]),  Clazz.newIntArray (-1, [4, 6, 5]),  Clazz.newIntArray (-1, [5, 7, 1]),  Clazz.newIntArray (-1, [1, 3, 0]),  Clazz.newIntArray (-1, [6, 2, 7]),  Clazz.newIntArray (-1, [1, 0, 5]),  Clazz.newIntArray (-1, [0, 2, 6]),  Clazz.newIntArray (-1, [6, 7, 5]),  Clazz.newIntArray (-1, [7, 3, 1]),  Clazz.newIntArray (-1, [3, 2, 0]),  Clazz.newIntArray (-1, [2, 3, 7]),  Clazz.newIntArray (-1, [0, 4, 5])]));
 c$.unitCubePoints = c$.prototype.unitCubePoints =  Clazz.newArray (-1, [JU.P3.new3 (0, 0, 0), JU.P3.new3 (0, 0, 1), JU.P3.new3 (0, 1, 0), JU.P3.new3 (0, 1, 1), JU.P3.new3 (1, 0, 0), JU.P3.new3 (1, 0, 1), JU.P3.new3 (1, 1, 0), JU.P3.new3 (1, 1, 1)]);
 Clazz.defineStatics (c$,
-"facePoints",  Clazz.newArray (-1, [ Clazz.newIntArray (-1, [4, 0, 6]),  Clazz.newIntArray (-1, [4, 6, 5]),  Clazz.newIntArray (-1, [5, 7, 1]),  Clazz.newIntArray (-1, [1, 3, 0]),  Clazz.newIntArray (-1, [6, 2, 7]),  Clazz.newIntArray (-1, [1, 0, 5]),  Clazz.newIntArray (-1, [0, 2, 6]),  Clazz.newIntArray (-1, [6, 7, 5]),  Clazz.newIntArray (-1, [7, 3, 1]),  Clazz.newIntArray (-1, [3, 2, 0]),  Clazz.newIntArray (-1, [2, 3, 7]),  Clazz.newIntArray (-1, [0, 4, 5])]),
 "toCanonical",  Clazz.newIntArray (-1, [0, 3, 4, 7, 1, 2, 5, 6]));
 c$.unitBboxPoints = c$.prototype.unitBboxPoints =  new Array (8);
 });
