@@ -89,7 +89,7 @@ case 1814695966:
 case 1812599299:
 var box = slabbingObject;
 sb.append ("within ").append (JU.Escape.eAP (box));
-var faces = this.getBoxFacesFromOABC (box);
+var faces = JU.BoxInfo.getBoxFacesFromOABC (box);
 for (var i = 0; i < faces.length; i++) {
 this.getIntersection (0, faces[i], null, null, null, null, null, andCap, false, 134217750, isGhost);
 }
@@ -132,23 +132,6 @@ if (m.slabOptions == null) m.slabOptions =  new JU.SB ();
 if (m.slabOptions.indexOf (newOptions) < 0) m.slabOptions.append (m.slabOptions.length () > 0 ? "; " : "").append (m.meshType).append (newOptions);
 return true;
 }, "~A,~B");
-Clazz.defineMethod (c$, "getBoxFacesFromOABC", 
- function (oabc) {
-var faces =  new Array (6);
-var vNorm =  new JU.V3 ();
-var vAB =  new JU.V3 ();
-var pta =  new JU.P3 ();
-var ptb =  new JU.P3 ();
-var ptc =  new JU.P3 ();
-var vertices = JU.BoxInfo.getVerticesFromOABC (oabc);
-for (var i = 0; i < 6; i++) {
-pta.setT (vertices[JU.BoxInfo.facePoints[i][0]]);
-ptb.setT (vertices[JU.BoxInfo.facePoints[i][1]]);
-ptc.setT (vertices[JU.BoxInfo.facePoints[i][2]]);
-faces[i] = JU.Measure.getPlaneThroughPoints (pta, ptb, ptc, vNorm, vAB,  new JU.P4 ());
-}
-return faces;
-}, "~A");
 Clazz.defineMethod (c$, "getIntersection", 
 function (distance, plane, ptCenters, vData, fData, bsSource, meshSurface, andCap, doClean, tokType, isGhost) {
 var m = this.m;
