@@ -228,6 +228,8 @@ this.modCalc.id = this.id;
 this.modCalc.modDim = this.modDim;
 this.modCalc.mods = this.mods;
 this.modCalc.nOps = this.nOps;
+this.modCalc.isSubsystem = this.isSubsystem;
+this.modCalc.tFactorInv = this.tFactorInv;
 this.modCalc.occParams = this.occParams;
 this.modCalc.occSiteMultiplicity = this.occSiteMultiplicity;
 this.modCalc.r0 = this.r0;
