@@ -386,7 +386,7 @@ if (fileName == null || this.vwr.$isKiosk) return null;
 var useDialog = fileName.startsWith ("?");
 if (useDialog) fileName = fileName.substring (1);
 useDialog = new Boolean (useDialog | (this.vwr.isApplet && fileName.indexOf ("http:") != 0 && fileName.indexOf ("https:") != 0)).valueOf ();
-fileName = JV.FileManager.getLocalPathForWritingFile (this.vwr, fileName);
+fileName = JV.FileManager.getLocalPathForWritingFile (this.vwr, fileName, useDialog);
 if (useDialog) fileName = this.vwr.dialogAsk (quality == -2147483648 ? "Save" : "Save Image", fileName, params);
 return fileName;
 }, "~S,~N,java.util.Map");
