@@ -133,7 +133,7 @@ function (x, y, modifiers, bsVisible, drawPicking) {
 var shape;
 var map = null;
 if (this.vwr.getPickingMode () == 2) {
-return this.shapes[5].checkObjectClicked (x, y, modifiers, bsVisible, false);
+return (this.shapes[5] == null ? null : this.shapes[5].checkObjectClicked (x, y, modifiers, bsVisible, false));
 }if (modifiers != 0 && this.vwr.getBondsPickable () && (map = this.shapes[1].checkObjectClicked (x, y, modifiers, bsVisible, false)) != null) return map;
 for (var i = 0; i < JV.ShapeManager.clickableMax; i++) if ((shape = this.shapes[JV.ShapeManager.hoverable[i]]) != null && (map = shape.checkObjectClicked (x, y, modifiers, bsVisible, drawPicking)) != null) return map;
 
