@@ -61,9 +61,9 @@ b;else if("hideAll"===a)this.showHide(b.booleanValue());else if("pending"===a)th
 null:(this.bsSelected=new JU.BS,this.bsSelected.or(b));else if("selectall"===a)this.bsSelected=JU.BSUtil.newBitSet2(0,this.measurementCount);else if("setFormats"===a)this.setFormats(b);else if(this.measureAllModels=this.vwr.getBoolean(603979877),"delete"===a)this.deleteO(b),this.setIndices();else{this.bsSelected=null;if("maps"===a)for(e=0;e<b.length;e++)d=b[e].length,2>d||4<d||(g=w(d+1,0),g[0]=d,System.arraycopy(b[e],0,g,1,d),this.toggleOn(g));else if("measure"===a){this.tickInfo=b.tickInfo;if(null!=
 b.tickInfo&&b.tickInfo.id.equals("default")){this.defaultTickInfo=b.tickInfo;return}if(b.isAll&&2==b.points.size()&&q(b.points.get(0),JU.BS))switch(JM.Measurement.nmrType(this.vwr.getDistanceUnits(b.strFormat))){case 2:b.htMin=this.vwr.getNMRCalculation().getMinDistances(b)}this.tickInfo=b.tickInfo;this.radiusData=b.radiusData;this.htMin=b.htMin;this.mustBeConnected=b.mustBeConnected;this.mustNotBeConnected=b.mustNotBeConnected;this.intramolecular=b.intramolecular;this.strFormat=b.strFormat;if(b.isAll){null!=
 this.tickInfo&&this.define(b,12291);null!=b.bsSelected&&(this.bsSelected=b.bsSelected);this.define(b,b.tokAction);this.setIndices();return}e=this.setSingleItem(b.points);e.setFromMD(b,!1);switch(b.tokAction){case 266284:this.doAction(b,b.thisID,266284);break;case 12291:this.defineAll(-2147483648,e,!0,!1,!1);this.setIndices();break;case 1073742335:this.showHideM(e,!1);break;case 1073742334:this.showHideM(e,!0);break;case 1665140738:null!=b.thisID&&this.doAction(b,b.thisID,1665140738);break;case 12290:null==
-b.thisID?this.deleteM(e):this.deleteO(b.thisID);this.toggle(e);break;case 1275082241:this.bsSelected=new JU.BS;this.processNextMeasure(b,e);break;case 268435538:this.toggle(e)}return}if("clear"===a)this.clear();else if("deleteAtoms"===a)for(e=this.measurementCount;0<=--e;){g=c.nextSetBit(0);a:for(;0<=g;g=c.nextSetBit(g+1)){d=this.measurements.get(e);b=d.countPlusIndices;for(a=1;a<=b[0];a++)if(b[a]==g){this.deleteI(e);break a}}}else if("deleteModelAtoms"===a){c=b[2][0];g=b[2][1];for(var f=b[2][2],
+b.thisID?this.deleteM(e):this.deleteO(b.thisID);this.toggle(e);break;case 1275082241:this.bsSelected=new JU.BS;this.processNextMeasure(b,e);break;case 268438018:this.toggle(e)}return}if("clear"===a)this.clear();else if("deleteAtoms"===a)for(e=this.measurementCount;0<=--e;){g=c.nextSetBit(0);a:for(;0<=g;g=c.nextSetBit(g+1)){d=this.measurements.get(e);b=d.countPlusIndices;for(a=1;a<=b[0];a++)if(b[a]==g){this.deleteI(e);break a}}}else if("deleteModelAtoms"===a){c=b[2][0];g=b[2][1];for(var f=b[2][2],
 j=g+f,e=this.measurementCount;0<=--e;){d=this.measurements.get(e);b=d.countPlusIndices;for(a=1;a<=b[0];a++){var k=b[a];if(k>=g){if(k<j){this.deleteI(e);break}b[a]-=f}else if(0>k)if(k=d.getAtom(a),k.mi>c)k.mi--;else if(k.mi==c){this.deleteI(e);break}}}}else"reformatDistances"===a?this.reformatDistances(null==b):"hide"===a?q(b,String)?this.doAction(null,b,12294):this.showHideM((new JM.Measurement).setPoints(this.ms,b,null,null),!0):"refresh"===a?this.doAction(b,null,266284):"show"===a?q(b,String)?this.doAction(null,
-b,134222350):this.showHideM((new JM.Measurement).setPoints(this.ms,b,null,null),!1):"toggle"===a?q(b,String)?this.doAction(null,b,268435538):this.toggle((new JM.Measurement).setPoints(this.ms,b,null,null)):"toggleOn"===a&&(q(b,String)?this.doAction(null,b,1073742335):this.toggleOn(b))}}},"~S,~O,JU.BS");f(c$,"setSingleItem",function(a){var b=Array(4),c=w(5,0);c[0]=a.size();for(var d=a.size();0<=--d;){var e=a.get(d);if(q(e,JU.BS)){e=e.nextSetBit(0);if(0>e)return null;c[d+1]=e}else b[d]=e,c[d+1]=-2-
+b,134222350):this.showHideM((new JM.Measurement).setPoints(this.ms,b,null,null),!1):"toggle"===a?q(b,String)?this.doAction(null,b,268438018):this.toggle((new JM.Measurement).setPoints(this.ms,b,null,null)):"toggleOn"===a&&(q(b,String)?this.doAction(null,b,1073742335):this.toggleOn(b))}}},"~S,~O,JU.BS");f(c$,"setSingleItem",function(a){var b=Array(4),c=w(5,0);c[0]=a.size();for(var d=a.size();0<=--d;){var e=a.get(d);if(q(e,JU.BS)){e=e.nextSetBit(0);if(0>e)return null;c[d+1]=e}else b[d]=e,c[d+1]=-2-
 d}return(new JM.Measurement).setPoints(this.ms,c,b,null==this.tickInfo?this.defaultTickInfo:this.tickInfo)},"JU.Lst");h(c$,"getProperty",function(a,b){return"pending".equals(a)?this.mPending:"count".equals(a)?Integer.$valueOf(this.measurementCount):"countPlusIndices".equals(a)?b<this.measurementCount?this.measurements.get(b).countPlusIndices:null:"stringValue".equals(a)?b<this.measurementCount?this.measurements.get(b).getString():null:"pointInfo".equals(a)?this.measurements.get(m(b/10)).getLabel(b%
 10,!1,!1):"info".equals(a)?this.getAllInfo():"infostring".equals(a)?this.getAllInfoAsString():"selected".equals(a)?null==this.bsSelected?new JU.BS:JU.BSUtil.copy(this.bsSelected):null},"~S,~N");f(c$,"clear",function(){0!=this.measurementCount&&(this.measurementCount=0,this.measurements.clear(),this.mPending=null,this.vwr.setStatusMeasuring("measureDeleted",-1,"all",0))});f(c$,"setColor",function(a){null==this.bsColixSet&&(this.bsColixSet=new JU.BS);null==this.bsSelected&&(this.colix=a);for(var b,
 c=this.measurements.size();0<=--c;)if(null!=(b=this.measurements.get(c))&&(null!=this.bsSelected&&this.bsSelected.get(c)||null==this.bsSelected&&(0==a||0==b.colix)))b.colix=a,this.bsColixSet.set(c)},"~N");f(c$,"setFormats",function(a){null!=a&&0==a.length&&(a=null);var b="default".equals(a);if(b||JM.Measurement.isUnits(a)){b&&(a=null);for(b=this.measurements.size();0<=--b;)if(null==this.bsSelected||this.bsSelected.get(b)){var c=this.measurements.get(b);c.units=a;c.formatMeasurement(null)}}else for(b=
@@ -73,10 +73,10 @@ c;0<=b&&!(c=this.measurements.get(b)).isHidden?this.defineAll(b,c,!0,!1,!1):this
 a.addLast(0<=f?this.ms.getAtoms(1094715393,Integer.$valueOf(e[f].getAtomNumber())):b.getAtom(g))}this.define((new JM.MeasurementData).init(null,this.vwr,a).set(this.tokAction,this.htMin,this.radiusData,b.property,this.strFormat,null,this.tickInfo,this.mustBeConnected,this.mustNotBeConnected,this.intramolecular,!0,0,0,null,NaN,null),c?12291:12290)}else c?(-2147483648==a&&(a=this.find(b)),0<=a&&this.deleteI(a)):this.defineMeasurement(a,b,e)},"~N,JM.Measurement,~B,~B,~B");f(c$,"find",function(a){return null==
 a.thisID?JM.Measurement.find(this.measurements,a):-1},"JM.Measurement");f(c$,"setIndices",function(){for(var a=0;a<this.measurementCount;a++)this.measurements.get(a).index=a});f(c$,"define",function(a,b){this.tokAction=b;if(null!=a.bsSelected)for(var c=this.measurementCount;0<=--c;)a.bsSelected.get(c)&&this.processNextMeasure(a,this.measurements.get(c));else 1275082241==b&&(this.bsSelected=new JU.BS),a.define(this,this.ms)},"JM.MeasurementData,~N");h(c$,"processNextMeasure",function(a,b){var c=this.find(b);
 if(1275082241==a.tokAction){if(0>c||!this.isInRange(NaN,b))return;this.bsSelected.set(c)}if(0<=c)12291==this.tokAction?this.isInRange(NaN,b)&&this.deleteI(c):1275082241==a.tokAction?(c=this.measurements.get(c),c.setFromMD(a,!0),null!=this.strFormat&&null==a.strFormat?c.formatMeasurementAs(this.strFormat,a.units,!0):null!=a.units&&(c.strFormat=null,c.units=a.units.equals("default")?null:a.units,c.formatMeasurement(null))):this.measurements.get(c).isHidden=1073742334==this.tokAction;else if(12290==
-this.tokAction||268435538==this.tokAction)b.tickInfo=null==this.tickInfo?this.defaultTickInfo:this.tickInfo,this.defineMeasurement(-1,b,!0)},"JM.MeasurementData,JM.Measurement");f(c$,"isInRange",function(a,b){return!(null!=this.htMin&&!b.isMin(this.htMin)||null!=this.radiusData&&!b.isInRange(this.radiusData,a==a?a:b.getMeasurement(null)))},"~N,JM.Measurement");f(c$,"defineMeasurement",function(a,b,c){var d=b.getMeasurement(null);this.isInRange(d,b)&&(-2147483648==a&&(a=this.find(b)),0<=a?(this.measurements.get(a).isHidden=
+this.tokAction||268438018==this.tokAction)b.tickInfo=null==this.tickInfo?this.defaultTickInfo:this.tickInfo,this.defineMeasurement(-1,b,!0)},"JM.MeasurementData,JM.Measurement");f(c$,"isInRange",function(a,b){return!(null!=this.htMin&&!b.isMin(this.htMin)||null!=this.radiusData&&!b.isInRange(this.radiusData,a==a?a:b.getMeasurement(null)))},"~N,JM.Measurement");f(c$,"defineMeasurement",function(a,b,c){var d=b.getMeasurement(null);this.isInRange(d,b)&&(-2147483648==a&&(a=this.find(b)),0<=a?(this.measurements.get(a).isHidden=
 !1,c&&this.bsSelected.set(a)):(a=(new JM.Measurement).setM(this.ms,b,d,0==b.colix?this.colix:b.colix,this.strFormat,this.measurementCount),a.$isValid&&(this.measurements.addLast(a),this.vwr.setStatusMeasuring("measureCompleted",this.measurementCount++,J.shape.Measures.getMessage(a,!1),a.value))))},"~N,JM.Measurement,~B");c$.getMessage=f(c$,"getMessage",function(a,b){var c=new JU.SB;c.append("[");for(var d=1;d<=a.count;d++)1<d&&c.append(", "),c.append(a.getLabel(d,b,!1));c.append(", ");c.append(a.getString());
 c.append("]");return c.toString()},"JM.Measurement,~B");f(c$,"deleteI",function(a){if(!(a>=this.measurements.size()||0>a)){var b=J.shape.Measures.getMessage(this.measurements.get(a),!0);this.measurements.removeItemAt(a);this.measurementCount--;this.vwr.setStatusMeasuring("measureDeleted",a,b,0);this.bsSelected=null}},"~N");f(c$,"doAction",function(a,b,c){b=b.toUpperCase().$replace("?","*");for(var d=JU.PT.isWild(b),e=this.measurements.size();0<=--e;){var g=this.measurements.get(e);if(null!=g.thisID&&
-(g.thisID.equalsIgnoreCase(b)||d&&JU.PT.isMatch(g.thisID.toUpperCase(),b,!0,!0)))switch(c){case 266284:g.setFromMD(a,!0);break;case 1665140738:g.mad=a.mad;break;case 12291:g=J.shape.Measures.getMessage(this.measurements.get(e),!0);this.measurements.removeItemAt(e);this.measurementCount--;this.vwr.setStatusMeasuring("measureDeleted",e,g,0);break;case 134222350:g.isHidden=!1;break;case 12294:g.isHidden=!0;break;case 268435538:g.isHidden=!g.isHidden;break;case 1073742335:g.isHidden=!1}}},"JM.MeasurementData,~S,~N");
+(g.thisID.equalsIgnoreCase(b)||d&&JU.PT.isMatch(g.thisID.toUpperCase(),b,!0,!0)))switch(c){case 266284:g.setFromMD(a,!0);break;case 1665140738:g.mad=a.mad;break;case 12291:g=J.shape.Measures.getMessage(this.measurements.get(e),!0);this.measurements.removeItemAt(e);this.measurementCount--;this.vwr.setStatusMeasuring("measureDeleted",e,g,0);break;case 134222350:g.isHidden=!1;break;case 12294:g.isHidden=!0;break;case 268438018:g.isHidden=!g.isHidden;break;case 1073742335:g.isHidden=!1}}},"JM.MeasurementData,~S,~N");
 f(c$,"reformatDistances",function(a){for(var b=this.measurementCount;0<=--b;)this.measurements.get(b).reformatDistanceIfSelected(a)},"~B");f(c$,"getAllInfo",function(){for(var a=new JU.Lst,b=0;b<this.measurementCount;b++)a.addLast(this.getInfo(b));return a});f(c$,"getAllInfoAsString",function(){for(var a="Measurement Information",b=0;b<this.measurementCount;b++)a+="\n"+this.getInfoAsString(b);return a});f(c$,"getInfo",function(a){var b=this.measurements.get(a),c=b.count,d=new java.util.Hashtable;
 d.put("index",Integer.$valueOf(a));d.put("type",2==c?"distance":3==c?"angle":"dihedral");d.put("strMeasurement",b.getString());d.put("count",Integer.$valueOf(c));d.put("id",""+b.thisID);d.put("value",Float.$valueOf(b.value));d.put("hidden",Boolean.$valueOf(b.isHidden));d.put("visible",Boolean.$valueOf(b.isVisible));a=b.tickInfo;null!=a&&(d.put("ticks",a.ticks),null!=a.scale&&d.put("tickScale",a.scale),null!=a.tickLabelFormats&&d.put("tickLabelFormats",a.tickLabelFormats),Float.isNaN(a.first)||d.put("tickStart",
 Float.$valueOf(a.first)));a=new JU.Lst;for(var e=this.ms.at,g=1;g<=c;g++){var f=new java.util.Hashtable,j=b.getAtomIndex(g);f.put("_ipt",Integer.$valueOf(j));f.put("coord",JU.Escape.eP(b.getAtom(g)));f.put("atomno",Integer.$valueOf(0>j?-1:e[j].getAtomNumber()));f.put("info",0>j?"<point>":e[j].getInfo());a.addLast(f)}d.put("atoms",a);return d},"~N");f(c$,"getInfoAsString",function(a){return this.measurements.get(a).getInfoAsString(null)},"~N");f(c$,"setVisibilityInfo",function(){var a=this.vwr.getVisibleFramesBitSet(),
@@ -128,6 +128,6 @@ a.valign&&J.render.TextRenderer.calcBarPixelsXYZ(this.tm,a,this.pt0i,!0);if(null
 a.atomZ=this.pt0i.z,-2147483648==a.zSlab&&(a.zSlab=1));J.render.TextRenderer.render(this.tm,a,this.g3d,this.sppm,this.imageFontScaling,null,this.xy,this.pt2i,0,0,b)&&(1==a.valign&&12==a.align)&&(this.vwr.noFrankEcho=!1);if(JU.C.renderPass2(a.bgcolix)||JU.C.renderPass2(a.colix))this.haveTranslucent=!0}},"JM.Text,~N");f(c$,"renderFrameTitle",function(a){this.vwr.gdata.setFontBold("arial",k(24*this.imageFontScaling));var b=m(Math.floor(this.vwr.getScreenHeight()*(this.g3d.isAntialiased()?2:1)-10*this.imageFontScaling)),
 c=m(Math.floor(5*this.imageFontScaling));this.g3d.drawStringNoSlab(a,null,c,b,0,0)},"~S")});p("J.render");r(["J.render.ShapeRenderer"],"J.render.HoverRenderer",["JU.P3","J.render.TextRenderer"],function(){c$=t(function(){this.ptTemp=this.tempXY=null;s(this,arguments)},J.render,"HoverRenderer",J.render.ShapeRenderer);v(c$,function(){this.tempXY=u(3,0)});h(c$,"render",function(){if(this.tm.isNavigating())return!1;null==this.ptTemp&&(this.ptTemp=new JU.P3);var a=this.shape,b=this.g3d.isAntialiased(),
 c=a.hoverText,d;if(0<=a.atomIndex){var e=this.ms.at[a.atomIndex];d=null!=a.specialLabel?a.specialLabel:null!=a.atomFormats&&null!=a.atomFormats[a.atomIndex]?this.ms.getLabeler().formatLabel(this.vwr,e,a.atomFormats[a.atomIndex],this.ptTemp):null!=a.labelFormat?this.ms.getLabeler().formatLabel(this.vwr,e,this.fixLabel(e,a.labelFormat),this.ptTemp):null;if(null==d)return!1;c.setXYZs(e.sX,e.sY,1,-2147483648)}else if(null!=a.text)d=a.text,c.setXYZs(a.xy.x,a.xy.y,1,-2147483648);else return!0;null!=this.vwr&&
-(d=this.vwr.formatText(d));c.setText(d);J.render.TextRenderer.render(null,c,this.g3d,0,b?2:1,null,this.tempXY,null,0,0,0);return!0});f(c$,"fixLabel",function(a,b){return null==b?null:this.ms.isJmolDataFrameForModel(a.mi)&&b.equals("%U")?"%W":b},"JM.Atom,~S")})})(Clazz,Clazz.getClassName,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,
+(d=this.vwr.formatText(d));c.setText(d);J.render.TextRenderer.render(null,c,this.g3d,0,b?2:1,null,this.tempXY,null,0,0,0);return!0});f(c$,"fixLabel",function(a,b){return null==b||null==a?null:this.ms.isJmolDataFrameForModel(a.mi)&&b.equals("%U")?"%W":b},"JM.Atom,~S")})})(Clazz,Clazz.getClassName,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,
 Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,
 Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAB,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
